(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     55613,       1456]
NotebookOptionsPosition[     52405,       1336]
NotebookOutlinePosition[     52763,       1352]
CellTagsIndexPosition[     52720,       1349]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["BWDifference function examples", "Title",
 CellChangeTimes->{{3.674456451129121*^9, 3.674456461911463*^9}, {
  3.712403174401956*^9, 3.712403179148404*^9}},
 TextAlignment->Center],

Cell[TextData[StyleBox["IMPORTANT: Prior to using these examples, please open \
the BenderWu installation file and follow the installation instructions \
there. To open this file execute the command below.",
 FontSize->24,
 FontColor->RGBColor[1, 0, 0]]], "Title",
 CellChangeTimes->{{3.6771682251997423`*^9, 3.6771683301080313`*^9}, {
  3.677168491151359*^9, 3.6771685264047127`*^9}},
 TextJustification->0.5],

Cell[BoxData[
 RowBox[{"SystemOpen", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", 
     "\"\<BenderWu_Installation.nb\>\""}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.677168389742983*^9, 3.6771684052822647`*^9}, 
   3.677168478591648*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "If the package is not loaded, load it with the command\n",
 Cell[BoxData[
  RowBox[{"Needs", "[", "\"\<BenderWu`\>\"", "]"}]], "Input",
  CellChangeTimes->{{3.674456480025242*^9, 3.674456486251505*^9}}]
}], "Chapter",
 CellChangeTimes->{{3.6972708444147673`*^9, 3.69727085043052*^9}, 
   3.712403189916456*^9, {3.712403432299046*^9, 3.71240343912954*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "The BWDifference function computes the perturbative expansion of the \
eigenvalue problem \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"h", "(", 
      RowBox[{"X", ",", "P"}], ")"}], 
     RowBox[{"\[Psi]", "(", "x", ")"}]}], "=", 
    RowBox[{"E\[Psi]", "(", "x", ")"}]}], TraditionalForm]], 
  "Subsubsection"],
 "\n\nWhere ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "=", 
    SuperscriptBox["e", "gx"]}], TraditionalForm]], "Subsubsection"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "=", 
    SuperscriptBox["e", "gp"]}], TraditionalForm]], "Subsubsection"],
 ", such that the commutator ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"[", 
     RowBox[{"x", ",", "p"}], "]"}], "=", "i"}], TraditionalForm]], 
  "Subsubsection"],
 ". The BWDifference function computes an expansion of \[Psi](x) and E as a \
power series in g. \n\nFurthermore the algorithm assumes that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", "(", 
    RowBox[{"X", ",", "P"}], ")"}], TraditionalForm]], "Subsubsection"],
 " attains a minimum when ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"p", "=", "0"}]}], TraditionalForm]], "Subsubsection"],
 ". In the vicinity of x=p=0 we have that\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"h", "~", 
      RowBox[{"h", "(", 
       RowBox[{"1", ",", "1"}], ")"}]}], "+", 
     RowBox[{
      FractionBox[
       SuperscriptBox["g", "2"], "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"A", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"B", " ", 
         SuperscriptBox["p", "2"]}], "+", 
        RowBox[{"C", "(", 
         RowBox[{
          RowBox[{"x", " ", "p"}], "+", 
          RowBox[{"p", " ", "x"}]}], ")"}]}], ")"}]}], "+"}], "..."}], 
   TraditionalForm]], "Subsubsection"],
 "\n\nThe ",
 Cell[BoxData[
  FormBox["BWDifference", TraditionalForm]], "Subsubsection"],
 " function then computes an expansion\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Psi]", " ", 
     RowBox[{"(", "x", ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["e", 
      RowBox[{"i", " ", 
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"\[Alpha]", "/", "2"}]}]], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Sum]", 
        RowBox[{"l", "=", "0"}]], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox["g", "l"], " ", 
       SuperscriptBox[
        SubscriptBox["A", "l"], "k"], " ", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Psi]", "k"], "(", 
         RowBox[{"x", "/", "\[Xi]"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"l", "/", "2"}]], 
          SqrtBox[
           RowBox[{"k", "!"}]]}], ")"}]}]}]}]}]}], TraditionalForm]], 
  "Subsubsection"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"E", "=", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[Sum]", 
       RowBox[{"l", "=", "0"}]], "\[Infinity]"], " ", 
     RowBox[{
      SubscriptBox["E", 
       RowBox[{"l", "-", "2"}]], " ", 
      SuperscriptBox["g", "l"]}]}]}], TraditionalForm]], "Subsubsection"],
 "\nwhere \[Alpha]=-C/B, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Xi]", "=", 
    RowBox[{"(", 
     FractionBox[
      SuperscriptBox["B", "2"], 
      RowBox[{"AB", "-", 
       SuperscriptBox["C", "2"]}]], ")"}]}], TraditionalForm]], 
  "Subsubsection"],
 " and where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Psi]", "k"], TraditionalForm]], "Subsubsection"],
 " are normalized Harmonic oscillator wave-functions of level k.\n\nThe \
function BWDifference computes the coefficients ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["A", "l"], "k"], TraditionalForm]], "Subsubsection"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", 
    RowBox[{"l", "-", "2"}]], TraditionalForm]], "Subsubsection"],
 " up to a specified order of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["g", "2"], TraditionalForm]], "Subsubsection"],
 ".\n\nFor example, consider the case where h=X+P+1/X+1/P. To compute the \
series expansion of \[Psi](x) and E, for level number 2 to order ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["g", "20"], TraditionalForm]], "Subsubsection"],
 ", we run the command"
}], "Subsubsection",
 CellChangeTimes->{{3.712376213280827*^9, 3.7123763271675377`*^9}, {
   3.712376368466467*^9, 3.712376445803706*^9}, {3.712376501136973*^9, 
   3.712376529019722*^9}, {3.712376559797531*^9, 3.712376610873757*^9}, {
   3.712376668504566*^9, 3.7123767227248297`*^9}, {3.712376805984461*^9, 
   3.712377687388529*^9}, {3.712377719856888*^9, 3.71237784274859*^9}, 
   3.712385817146553*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BW", "=", 
   RowBox[{"BWDifference", "[", 
    RowBox[{
     RowBox[{"X", "+", "P", "+", 
      RowBox[{"1", "/", "X"}], "+", 
      RowBox[{"1", "/", "P"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", "P"}], "}"}], ",", "2", ",", "10"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.712377688519185*^9, 3.712377693596671*^9}, {
  3.712377726751357*^9, 3.712377742589479*^9}, {3.7123778454598293`*^9, 
  3.712377850140465*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Notice that the first argument specifies the operator h(X,P), the second \
argument specifies the symbols used for X and P, the third argument specifies \
the level number, and the fourth argument specifies the order of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["g", "2"], TraditionalForm]], "Subsubsection"],
 ".\n\nThe first element of BW variable defined above gives the list ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["E", 
      RowBox[{"-", "2"}]], ",", 
     SubscriptBox["E", "0"], ",", 
     SubscriptBox["E", "2"], ",", 
     SubscriptBox["E", "4"], ",", "..."}]}], TraditionalForm]], 
  "Subsubsection"],
 "} (the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "l"], TraditionalForm]], "Subsubsection"],
 " for ",
 Cell[BoxData[
  FormBox["l", TraditionalForm]], "Subsubsection"],
 "=",
 "odd vanishes), i.e."
}], "Subsubsection",
 CellChangeTimes->{{3.71237785399025*^9, 3.7123779276518087`*^9}, {
   3.712378073859948*^9, 3.712378184543172*^9}, 3.71238582533008*^9, {
   3.712403742841482*^9, 3.712403751726891*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BW", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.712377928877576*^9, 3.7123779306300297`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "5", ",", 
   FractionBox["13", "8"], ",", 
   FractionBox["35", "192"], ",", 
   FractionBox["17", "384"], ",", 
   RowBox[{"-", 
    FractionBox["805", "49152"]}], ",", 
   FractionBox["79079", "5898240"], ",", 
   RowBox[{"-", 
    FractionBox["1476017", "132120576"]}], ",", 
   FractionBox["54072859", "5284823040"], ",", 
   RowBox[{"-", 
    FractionBox["882298567", "86973087744"]}], ",", 
   FractionBox["1311914694689", "121762322841600"], ",", 
   RowBox[{"-", 
    FractionBox["7441989313763", "612290537717760"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.712377931616578*^9, 3.712385812614373*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The second element is a matrix of coefficients ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["A", "l"], "k"], TraditionalForm]]],
 ", i.e."
}], "Subsubsection",
 CellChangeTimes->{{3.7123779368306828`*^9, 3.71237796154136*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BW", "[", 
   RowBox[{"[", "2", "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.7123779631553288`*^9, 3.712377967792251*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["15", "8"]}], "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["81", "64"], "0", "0", "0", 
      FractionBox["1575", "64"], "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1725", "2048"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["9315", "256"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["525525", "512"]}], "0", "0", "0", "0", "0", "0", "0", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["9855", "16384"], "0", "0", "0", 
      FractionBox["338247", "8192"], "0", "0", "0", 
      FractionBox["10135125", "4096"], "0", "0", "0", 
      FractionBox["402026625", "4096"], "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["123589", "262144"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1441125", "32768"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["539880705", "131072"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["2791213425", "8192"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["588164952375", "32768"]}], "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["854685", "2097152"], "0", "0", "0", 
      FractionBox["196486395", "4194304"], "0", "0", "0", 
      FractionBox["6300390789", "1048576"], "0", "0", "0", 
      FractionBox["201500070525", "262144"], "0", "0", "0", 
      FractionBox["21930150367125", "262144"], "0", "0", "0", 
      FractionBox["1465511006334375", "262144"], "0", "0", "0", "0", "0", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["3262611995", "8455716864"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["860510763", "16777216"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["279832317765", "33554432"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["381368529045", "262144"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["2041665463062225", "8388608"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["35046648922910625", "1048576"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["5737475589799078125", "2097152"]}], "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["2971789221", "7516192768"], "0", "0", "0", 
      FractionBox["94164143215", "1610612736"], "0", "0", "0", 
      FractionBox["3071936252385", "268435456"], "0", "0", "0", 
      FractionBox["340224558644943", "134217728"], "0", "0", "0", 
      FractionBox["38656895249562975", "67108864"], "0", "0", "0", 
      FractionBox["4065598882217998125", "33554432"], "0", "0", "0", 
      FractionBox["340806050034065240625", "16777216"], "0", "0", "0", 
      FractionBox["33260145994065255890625", "16777216"], "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["2346592687997", "5411658792960"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["149772457155", "2147483648"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["102094681185497", "6442450944"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1141862441803965", "268435456"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["41104924433617275", "33554432"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["46857750984005729625", "134217728"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["48026995401984932458125", "536870912"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["299341313946587303015625", "16777216"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["272788630727991873729609375", "134217728"]}], "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["485465416349", "962072674304"], "0", "0", "0", 
      FractionBox["35940775010357", "412316860416"], "0", "0", "0", 
      FractionBox["192459274226505", "8589934592"], "0", "0", "0", 
      FractionBox["15140896418145505", "2147483648"], "0", "0", "0", 
      FractionBox["10566139912407007929", "4294967296"], "0", "0", "0", 
      FractionBox["15237438163259590585125", "17179869184"], "0", "0", "0", 
      FractionBox["1320478571796351625783125", "4294967296"], "0", "0", "0", 
      FractionBox["50246232138218774536003125", "536870912"], "0", "0", "0", 
      FractionBox["23358500751194047016218265625", "1073741824"], "0", "0", 
      "0", 
      FractionBox["3053323143738413042655517734375", "1073741824"], "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.712377968220448*^9, 3.712385812651733*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Alternatively the output can be achieved by the ",
 Cell[BoxData[
  FormBox["BWProcess", TraditionalForm]], "Subchapter"],
 " function"
}], "Subsubsection",
 CellChangeTimes->{{3.712377983012175*^9, 3.712378049429986*^9}, {
   3.712378200191661*^9, 3.7123782267472677`*^9}, {3.712378326126789*^9, 
   3.712378349269342*^9}, {3.712378528507029*^9, 3.712378529521006*^9}, 
   3.712385830601856*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", "BW", "]"}]], "Input",
 CellChangeTimes->{{3.712378020475778*^9, 3.712378022717739*^9}, {
  3.7123780557290497`*^9, 3.712378064267589*^9}, {3.7123781946049433`*^9, 
  3.7123781980591183`*^9}, {3.712378232473815*^9, 3.712378238563499*^9}, {
  3.712378350994301*^9, 3.7123783568252163`*^9}, {3.712378532570704*^9, 
  3.7123785327355423`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "5", ",", 
   FractionBox["13", "8"], ",", 
   FractionBox["35", "192"], ",", 
   FractionBox["17", "384"], ",", 
   RowBox[{"-", 
    FractionBox["805", "49152"]}], ",", 
   FractionBox["79079", "5898240"], ",", 
   RowBox[{"-", 
    FractionBox["1476017", "132120576"]}], ",", 
   FractionBox["54072859", "5284823040"], ",", 
   RowBox[{"-", 
    FractionBox["882298567", "86973087744"]}], ",", 
   FractionBox["1311914694689", "121762322841600"], ",", 
   RowBox[{"-", 
    FractionBox["7441989313763", "612290537717760"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.712378227912385*^9, 3.712378239485848*^9}, 
   3.712378358448472*^9, 3.71237853321735*^9, 3.712385812741119*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "In the same function an option ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Output", "\[Rule]", "\"\<WaveFunction\>\""}], TraditionalForm]], 
  "Subchapter"],
 " will return the matrix of the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["A", "l"], "k"], TraditionalForm]], "Subchapter"],
 " coefficients"
}], "Subsubsection",
 CellChangeTimes->{{3.712378244193429*^9, 3.7123782630700006`*^9}, {
  3.712378536334711*^9, 3.7123785555636473`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BWProcess", "[", 
   RowBox[{"BW", ",", 
    RowBox[{"Output", "\[Rule]", "\"\<WaveFunction\>\""}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.712378269433848*^9, 3.712378273704893*^9}, 
   3.7123783650628347`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["15", "8"]}], "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["81", "64"], "0", "0", "0", 
      FractionBox["1575", "64"], "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1725", "2048"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["9315", "256"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["525525", "512"]}], "0", "0", "0", "0", "0", "0", "0", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["9855", "16384"], "0", "0", "0", 
      FractionBox["338247", "8192"], "0", "0", "0", 
      FractionBox["10135125", "4096"], "0", "0", "0", 
      FractionBox["402026625", "4096"], "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["123589", "262144"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1441125", "32768"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["539880705", "131072"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["2791213425", "8192"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["588164952375", "32768"]}], "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["854685", "2097152"], "0", "0", "0", 
      FractionBox["196486395", "4194304"], "0", "0", "0", 
      FractionBox["6300390789", "1048576"], "0", "0", "0", 
      FractionBox["201500070525", "262144"], "0", "0", "0", 
      FractionBox["21930150367125", "262144"], "0", "0", "0", 
      FractionBox["1465511006334375", "262144"], "0", "0", "0", "0", "0", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["3262611995", "8455716864"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["860510763", "16777216"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["279832317765", "33554432"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["381368529045", "262144"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["2041665463062225", "8388608"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["35046648922910625", "1048576"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["5737475589799078125", "2097152"]}], "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["2971789221", "7516192768"], "0", "0", "0", 
      FractionBox["94164143215", "1610612736"], "0", "0", "0", 
      FractionBox["3071936252385", "268435456"], "0", "0", "0", 
      FractionBox["340224558644943", "134217728"], "0", "0", "0", 
      FractionBox["38656895249562975", "67108864"], "0", "0", "0", 
      FractionBox["4065598882217998125", "33554432"], "0", "0", "0", 
      FractionBox["340806050034065240625", "16777216"], "0", "0", "0", 
      FractionBox["33260145994065255890625", "16777216"], "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["2346592687997", "5411658792960"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["149772457155", "2147483648"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["102094681185497", "6442450944"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1141862441803965", "268435456"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["41104924433617275", "33554432"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["46857750984005729625", "134217728"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["48026995401984932458125", "536870912"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["299341313946587303015625", "16777216"]}], "0", "0", "0", 
      RowBox[{"-", 
       FractionBox["272788630727991873729609375", "134217728"]}], "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["485465416349", "962072674304"], "0", "0", "0", 
      FractionBox["35940775010357", "412316860416"], "0", "0", "0", 
      FractionBox["192459274226505", "8589934592"], "0", "0", "0", 
      FractionBox["15140896418145505", "2147483648"], "0", "0", "0", 
      FractionBox["10566139912407007929", "4294967296"], "0", "0", "0", 
      FractionBox["15237438163259590585125", "17179869184"], "0", "0", "0", 
      FractionBox["1320478571796351625783125", "4294967296"], "0", "0", "0", 
      FractionBox["50246232138218774536003125", "536870912"], "0", "0", "0", 
      FractionBox["23358500751194047016218265625", "1073741824"], "0", "0", 
      "0", 
      FractionBox["3053323143738413042655517734375", "1073741824"], "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7123782745466013`*^9, 3.712378366261203*^9, 
  3.712385812814389*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Note that these outputs can also be reproduced by calling ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Output", "\[Rule]", "\"\<Energy\>\""}], TraditionalForm]], 
  "Subchapter"],
 " or ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Output", "\[Rule]", "\"\<WaveFunction\>\""}], TraditionalForm]], 
  "Subchapter"],
 " in the BWDifference function.",
 "\n\n",
 "To output the series in g, and option OutputStyle can be used"
}], "Subsubsection",
 CellChangeTimes->{{3.712378373130253*^9, 3.712378427999136*^9}, {
  3.712378573855297*^9, 3.712378655835775*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7123784291892853`*^9, 3.7123784447398043`*^9}}],

Cell[BoxData[
 RowBox[{"5", "+", 
  FractionBox["4", 
   SuperscriptBox["g", "2"]], "+", 
  FractionBox[
   RowBox[{"13", " ", 
    SuperscriptBox["g", "2"]}], "8"], "+", 
  FractionBox[
   RowBox[{"35", " ", 
    SuperscriptBox["g", "4"]}], "192"], "+", 
  FractionBox[
   RowBox[{"17", " ", 
    SuperscriptBox["g", "6"]}], "384"], "-", 
  FractionBox[
   RowBox[{"805", " ", 
    SuperscriptBox["g", "8"]}], "49152"], "+", 
  FractionBox[
   RowBox[{"79079", " ", 
    SuperscriptBox["g", "10"]}], "5898240"], "-", 
  FractionBox[
   RowBox[{"1476017", " ", 
    SuperscriptBox["g", "12"]}], "132120576"], "+", 
  FractionBox[
   RowBox[{"54072859", " ", 
    SuperscriptBox["g", "14"]}], "5284823040"], "-", 
  FractionBox[
   RowBox[{"882298567", " ", 
    SuperscriptBox["g", "16"]}], "86973087744"], "+", 
  FractionBox[
   RowBox[{"1311914694689", " ", 
    SuperscriptBox["g", "18"]}], "121762322841600"], "-", 
  FractionBox[
   RowBox[{"7441989313763", " ", 
    SuperscriptBox["g", "20"]}], "612290537717760"]}]], "Output",
 CellChangeTimes->{3.712378445696591*^9, 3.7123858128936*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
To change the parameter of expansion, the option Coupling can be used\
\>", "Subsubsection",
 CellChangeTimes->{{3.7123784562617207`*^9, 3.712378469400309*^9}, 
   3.712385839106391*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}], ",", 
   RowBox[{"Coupling", "\[Rule]", 
    RowBox[{"Sqrt", "[", "\[HBar]", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.712378476851297*^9, 3.712378486904043*^9}}],

Cell[BoxData[
 RowBox[{"5", "+", 
  FractionBox["4", "\[HBar]"], "+", 
  FractionBox[
   RowBox[{"13", " ", "\[HBar]"}], "8"], "+", 
  FractionBox[
   RowBox[{"35", " ", 
    SuperscriptBox["\[HBar]", "2"]}], "192"], "+", 
  FractionBox[
   RowBox[{"17", " ", 
    SuperscriptBox["\[HBar]", "3"]}], "384"], "-", 
  FractionBox[
   RowBox[{"805", " ", 
    SuperscriptBox["\[HBar]", "4"]}], "49152"], "+", 
  FractionBox[
   RowBox[{"79079", " ", 
    SuperscriptBox["\[HBar]", "5"]}], "5898240"], "-", 
  FractionBox[
   RowBox[{"1476017", " ", 
    SuperscriptBox["\[HBar]", "6"]}], "132120576"], "+", 
  FractionBox[
   RowBox[{"54072859", " ", 
    SuperscriptBox["\[HBar]", "7"]}], "5284823040"], "-", 
  FractionBox[
   RowBox[{"882298567", " ", 
    SuperscriptBox["\[HBar]", "8"]}], "86973087744"], "+", 
  FractionBox[
   RowBox[{"1311914694689", " ", 
    SuperscriptBox["\[HBar]", "9"]}], "121762322841600"], "-", 
  FractionBox[
   RowBox[{"7441989313763", " ", 
    SuperscriptBox["\[HBar]", "10"]}], "612290537717760"]}]], "Output",
 CellChangeTimes->{3.712378487269658*^9, 3.7123858130089493`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "To truncate the series to a particular order in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["g", "2"], TraditionalForm]]],
 " use option Order "
}], "Subsubsection",
 CellChangeTimes->{{3.7123787048921547`*^9, 3.712378735850809*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}], ",", 
   RowBox[{"Order", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.712378739573181*^9, 3.712378745017332*^9}}],

Cell[BoxData[
 RowBox[{"5", "+", 
  FractionBox["4", 
   SuperscriptBox["g", "2"]], "+", 
  FractionBox[
   RowBox[{"13", " ", 
    SuperscriptBox["g", "2"]}], "8"], "+", 
  FractionBox[
   RowBox[{"35", " ", 
    SuperscriptBox["g", "4"]}], "192"], "+", 
  FractionBox[
   RowBox[{"17", " ", 
    SuperscriptBox["g", "6"]}], "384"]}]], "Output",
 CellChangeTimes->{3.712378745762903*^9, 3.712385813183964*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
To output the wavefunction as a series, the same options can be used\
\>", "Subsubsection",
 CellChangeTimes->{{3.7123784975225773`*^9, 3.712378514366272*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Output", "\[Rule]", "\"\<WaveFunction\>\""}], ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}], ",", 
   RowBox[{"Order", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.712378494940508*^9, 3.712378495570435*^9}, {
  3.71237868219698*^9, 3.712378693614236*^9}, {3.712378751044386*^9, 
  3.7123787531666403`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], "+", 
  SuperscriptBox["x", "2"], "+", 
  RowBox[{
   FractionBox["1", "384"], " ", 
   SuperscriptBox["g", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"15", "-", 
     RowBox[{"90", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"60", " ", 
      SuperscriptBox["x", "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["x", "6"]}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["g", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "24165"}], "+", 
      RowBox[{"163890", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"140760", " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"35568", " ", 
       SuperscriptBox["x", "6"]}], "-", 
      RowBox[{"3600", " ", 
       SuperscriptBox["x", "8"]}], "+", 
      RowBox[{"160", " ", 
       SuperscriptBox["x", "10"]}]}], ")"}]}], "737280"], "+", 
  RowBox[{
   FractionBox["1", "2972712960"], 
   RowBox[{
    SuperscriptBox["g", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"85062285", "-", 
      RowBox[{"660885750", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"716669100", " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{"266341320", " ", 
       SuperscriptBox["x", "6"]}], "+", 
      RowBox[{"46686960", " ", 
       SuperscriptBox["x", "8"]}], "-", 
      RowBox[{"4317216", " ", 
       SuperscriptBox["x", "10"]}], "+", 
      RowBox[{"203840", " ", 
       SuperscriptBox["x", "12"]}], "-", 
      RowBox[{"4480", " ", 
       SuperscriptBox["x", "14"]}]}], ")"}]}]}], "+", 
  RowBox[{
   FractionBox["1", "11415217766400"], 
   RowBox[{
    SuperscriptBox["g", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "315604506735"}], "+", 
      RowBox[{"2807234038350", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"3724167358800", " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"1818379977120", " ", 
       SuperscriptBox["x", "6"]}], "-", 
      RowBox[{"442815478560", " ", 
       SuperscriptBox["x", "8"]}], "+", 
      RowBox[{"61021187136", " ", 
       SuperscriptBox["x", "10"]}], "-", 
      RowBox[{"5005728000", " ", 
       SuperscriptBox["x", "12"]}], "+", 
      RowBox[{"247104000", " ", 
       SuperscriptBox["x", "14"]}], "-", 
      RowBox[{"6854400", " ", 
       SuperscriptBox["x", "16"]}], "+", 
      RowBox[{"89600", " ", 
       SuperscriptBox["x", "18"]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.712378694434043*^9, 3.7123787539713163`*^9, 
  3.712385813350731*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["To include the exponential prefactor, call", "Subsubsection",
 CellChangeTimes->{{3.7123787607143803`*^9, 3.7123788010600147`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Output", "\[Rule]", "\"\<WaveFunction\>\""}], ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}], ",", 
   RowBox[{"Order", "\[Rule]", "4"}], ",", 
   RowBox[{"Prefactor", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.712378787171319*^9, 3.712378791142742*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["x", "2"], "2"]}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], "+", 
    SuperscriptBox["x", "2"], "+", 
    RowBox[{
     FractionBox["1", "384"], " ", 
     SuperscriptBox["g", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"15", "-", 
       RowBox[{"90", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       RowBox[{"60", " ", 
        SuperscriptBox["x", "4"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["x", "6"]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["g", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "24165"}], "+", 
        RowBox[{"163890", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"140760", " ", 
         SuperscriptBox["x", "4"]}], "+", 
        RowBox[{"35568", " ", 
         SuperscriptBox["x", "6"]}], "-", 
        RowBox[{"3600", " ", 
         SuperscriptBox["x", "8"]}], "+", 
        RowBox[{"160", " ", 
         SuperscriptBox["x", "10"]}]}], ")"}]}], "737280"], "+", 
    RowBox[{
     FractionBox["1", "2972712960"], 
     RowBox[{
      SuperscriptBox["g", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"85062285", "-", 
        RowBox[{"660885750", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"716669100", " ", 
         SuperscriptBox["x", "4"]}], "-", 
        RowBox[{"266341320", " ", 
         SuperscriptBox["x", "6"]}], "+", 
        RowBox[{"46686960", " ", 
         SuperscriptBox["x", "8"]}], "-", 
        RowBox[{"4317216", " ", 
         SuperscriptBox["x", "10"]}], "+", 
        RowBox[{"203840", " ", 
         SuperscriptBox["x", "12"]}], "-", 
        RowBox[{"4480", " ", 
         SuperscriptBox["x", "14"]}]}], ")"}]}]}], "+", 
    RowBox[{
     FractionBox["1", "11415217766400"], 
     RowBox[{
      SuperscriptBox["g", "8"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "315604506735"}], "+", 
        RowBox[{"2807234038350", " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"3724167358800", " ", 
         SuperscriptBox["x", "4"]}], "+", 
        RowBox[{"1818379977120", " ", 
         SuperscriptBox["x", "6"]}], "-", 
        RowBox[{"442815478560", " ", 
         SuperscriptBox["x", "8"]}], "+", 
        RowBox[{"61021187136", " ", 
         SuperscriptBox["x", "10"]}], "-", 
        RowBox[{"5005728000", " ", 
         SuperscriptBox["x", "12"]}], "+", 
        RowBox[{"247104000", " ", 
         SuperscriptBox["x", "14"]}], "-", 
        RowBox[{"6854400", " ", 
         SuperscriptBox["x", "16"]}], "+", 
        RowBox[{"89600", " ", 
         SuperscriptBox["x", "18"]}]}], ")"}]}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.7123787916340714`*^9, 3.7123858134323874`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
If the wave-function has imaginary coefficient the execution can be quite slow\
\>", "Subsubsection",
 CellChangeTimes->{{3.70746672907999*^9, 3.707466751395714*^9}, {
  3.707466783827924*^9, 3.70746679974815*^9}, {3.712378833445622*^9, 
  3.7123788537523108`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BW", "=", 
    RowBox[{"BWDifference", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "X"}], "+", 
       RowBox[{
        RowBox[{"3", "/", "2"}], "/", "X"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "4"}], "/", 
         RowBox[{"X", "^", "2"}]}], "/", "P"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "X"}], "}"}], ",", "0", ",", "15"}], "]"}]}], ";"}], 
  "//", "Timing"}]], "Input",
 CellChangeTimes->{{3.707455180875196*^9, 3.707455228560606*^9}, {
   3.7074565125364447`*^9, 3.7074565126206007`*^9}, {3.7074584899077682`*^9, 
   3.707458495619637*^9}, 3.7074586286646433`*^9, {3.7074587246052017`*^9, 
   3.707458724638291*^9}, {3.707458773579776*^9, 3.707458774024621*^9}, {
   3.707458827173169*^9, 3.707458839419755*^9}, {3.707459353963213*^9, 
   3.707459355503731*^9}, {3.707466754748609*^9, 3.707466755619055*^9}, {
   3.712378908112734*^9, 3.7123789372081137`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10.664`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{{3.707455193895459*^9, 3.707455241373693*^9}, 
   3.707455613145129*^9, {3.707456514411868*^9, 3.707456531408712*^9}, 
   3.7074566090718307`*^9, {3.70745663915656*^9, 3.707456757842082*^9}, {
   3.707456799714679*^9, 3.70745682386581*^9}, {3.7074569312554827`*^9, 
   3.707456935577194*^9}, {3.707456979103541*^9, 3.707456990157358*^9}, {
   3.707457970039836*^9, 3.707457994581853*^9}, {3.7074581001920757`*^9, 
   3.707458112468186*^9}, {3.707458148537735*^9, 3.7074582823153353`*^9}, 
   3.707458329322782*^9, {3.707458361434208*^9, 3.707458497189455*^9}, 
   3.707458528867943*^9, {3.7074586033223867`*^9, 3.7074586293479357`*^9}, 
   3.707458725550295*^9, 3.707458780860485*^9, {3.70745883392866*^9, 
   3.707458845269844*^9}, 3.7074591082881823`*^9, {3.707459334375839*^9, 
   3.707459360108715*^9}, 3.707466804115678*^9, 3.7123762003664627`*^9, {
   3.712378906950021*^9, 3.712378950549879*^9}, 3.7123858242540483`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "If this occurs, the efficiency can be improved by calling the option ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Imaginary", "\[Rule]", "True"}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.707466762937169*^9, 3.7074668261943703`*^9}, {
  3.712378860640987*^9, 3.712378887248699*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BW", "=", 
    RowBox[{"BWDifference", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "X"}], "+", 
       RowBox[{
        RowBox[{"3", "/", "2"}], "/", "X"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "4"}], "/", 
         RowBox[{"X", "^", "2"}]}], "/", "P"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "X"}], "}"}], ",", "0", ",", "15", ",", 
      RowBox[{"Imaginary", "\[Rule]", "True"}]}], "]"}]}], ";"}], "//", 
  "Timing"}]], "Input",
 CellChangeTimes->{
  3.707461223884905*^9, {3.707461264951375*^9, 3.707461265761716*^9}, {
   3.7074667800111094`*^9, 3.707466780539401*^9}, {3.71237892507425*^9, 
   3.7123789418267393`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.06`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{
  3.707461319729639*^9, {3.7074668330111637`*^9, 3.707466850462669*^9}, 
   3.7123789570972967`*^9, 3.712385827645474*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The ordering of X and P in the second argument can also change the execution \
time\
\>", "Subsubsection",
 CellChangeTimes->{{3.712378980105118*^9, 3.7123789989196463`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BW", "=", 
    RowBox[{"BWDifference", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "X"}], "+", 
       RowBox[{
        RowBox[{"3", "/", "2"}], "/", "X"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "4"}], "/", 
         RowBox[{"X", "^", "2"}]}], "/", "P"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"X", ",", "P"}], "}"}], ",", "0", ",", "15", ",", 
      RowBox[{"Imaginary", "\[Rule]", "True"}]}], "]"}]}], ";"}], "//", 
  "Timing"}]], "Input",
 CellChangeTimes->{{3.712379007008861*^9, 3.712379008319785*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.052`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.712379019112842*^9, 3.7123858338885517`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
However is there is no imaginary part of the wave-function, then the \
execution is faster if the option is not used\
\>", "Subsubsection",
 CellChangeTimes->{{3.7074669258586493`*^9, 3.7074669502228203`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BW", "=", 
    RowBox[{"BWDifference", "[", 
     RowBox[{
      RowBox[{"X", "+", "P", "+", 
       RowBox[{
        RowBox[{"1", "/", "X"}], "/", "P"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "X"}], "}"}], ",", "0", ",", "20", ",", 
      RowBox[{"Imaginary", "\[Rule]", "False"}]}], "]"}]}], ";"}], "//", 
  "Timing"}]], "Input",
 CellChangeTimes->{{3.712379033042234*^9, 3.712379067164603*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.528`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.707466958313458*^9, 3.712379044273183*^9, 
  3.7123790845718203`*^9, 3.712385836631659*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BW", "=", 
    RowBox[{"BWDifference", "[", 
     RowBox[{
      RowBox[{"X", "+", "P", "+", 
       RowBox[{
        RowBox[{"1", "/", "X"}], "/", "P"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"P", ",", "X"}], "}"}], ",", "0", ",", "20", ",", 
      RowBox[{"Imaginary", "\[Rule]", "True"}]}], "]"}]}], ";"}], "//", 
  "Timing"}]], "Input",
 CellChangeTimes->{{3.7074668921237698`*^9, 3.707466896816909*^9}, {
  3.712379047862246*^9, 3.712379070848447*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.648`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{
  3.707466904360064*^9, 3.707466967669012*^9, {3.712379057285273*^9, 
   3.712379078648014*^9}, 3.712385840459153*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1078, 839},
WindowMargins->{{44, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->"Blue Theme.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 186, 3, 92, "Title"],
Cell[769, 27, 410, 7, 102, "Title"],
Cell[1182, 36, 324, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[1531, 48, 373, 7, 84, "Chapter"],
Cell[CellGroupData[{
Cell[1929, 59, 4695, 148, 532, "Subsubsection"],
Cell[6627, 209, 476, 13, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7140, 227, 1089, 30, 110, "Subsubsection"],
Cell[CellGroupData[{
Cell[8254, 261, 146, 3, 28, "Input"],
Cell[8403, 266, 660, 17, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9112, 289, 264, 8, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[9401, 301, 180, 4, 28, "Input"],
Cell[9584, 307, 11704, 197, 467, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21337, 510, 414, 9, 45, "Subsubsection"],
Cell[CellGroupData[{
Cell[21776, 523, 381, 6, 28, "Input"],
Cell[22160, 531, 731, 18, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22940, 555, 478, 14, 47, "Subsubsection"],
Cell[CellGroupData[{
Cell[23443, 573, 272, 7, 28, "Input"],
Cell[23718, 582, 10927, 191, 449, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34694, 779, 568, 16, 131, "Subsubsection"],
Cell[CellGroupData[{
Cell[35287, 799, 209, 4, 28, "Input"],
Cell[35499, 805, 1097, 34, 94, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36645, 845, 196, 4, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[36866, 853, 291, 6, 28, "Input"],
Cell[37160, 861, 1111, 32, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38320, 899, 254, 7, 37, "Subsubsection"],
Cell[CellGroupData[{
Cell[38599, 910, 249, 5, 28, "Input"],
Cell[38851, 917, 410, 13, 53, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39310, 936, 169, 3, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[39504, 943, 412, 8, 28, "Input"],
Cell[39919, 953, 2571, 78, 136, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42539, 1037, 137, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[42701, 1042, 364, 7, 28, "Input"],
Cell[43068, 1051, 2852, 83, 160, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45969, 1140, 275, 5, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[46269, 1149, 975, 23, 28, "Input"],
Cell[47247, 1174, 1029, 15, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48325, 1195, 317, 7, 37, "Subsubsection"],
Cell[CellGroupData[{
Cell[48667, 1206, 731, 21, 28, "Input"],
Cell[49401, 1229, 223, 5, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49673, 1240, 184, 4, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[49882, 1248, 603, 18, 28, "Input"],
Cell[50488, 1268, 147, 3, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50684, 1277, 219, 4, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[50928, 1285, 459, 13, 28, "Input"],
Cell[51390, 1300, 194, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51621, 1309, 509, 14, 28, "Input"],
Cell[52133, 1325, 220, 5, 28, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

