(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    143511,       3710]
NotebookOptionsPosition[    136150,       3449]
NotebookOutlinePosition[    136733,       3472]
CellTagsIndexPosition[    136645,       3467]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["BenderWu package examples", "Title",
 CellChangeTimes->{{3.674456451129121*^9, 3.674456461911463*^9}},
 TextAlignment->Center],

Cell[TextData[StyleBox["IMPORTANT: Prior to using these examples, please open \
the BenderWu installation file and follow the installation instructions \
there. To open this file execute the command below.",
 FontSize->24,
 FontColor->RGBColor[1, 0, 0]]], "Title",
 CellChangeTimes->{{3.6771682251997423`*^9, 3.6771683301080313`*^9}, {
  3.677168491151359*^9, 3.6771685264047127`*^9}},
 TextJustification->0.5],

Cell[BoxData[
 RowBox[{"SystemOpen", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", 
     "\"\<BenderWu_Installation.nb\>\""}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.677168389742983*^9, 3.6771684052822647`*^9}, 
   3.677168478591648*^9}],

Cell[CellGroupData[{

Cell["If the package is not loaded, load it with the command", "Chapter",
 CellChangeTimes->{{3.674456466986608*^9, 3.67445647771115*^9}}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<BenderWu`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.674456480025242*^9, 3.674456486251505*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["To get help using BenderWu function, call", "Chapter",
 CellChangeTimes->{{3.674456497553192*^9, 3.674456505801305*^9}, {
  3.6747351844444637`*^9, 3.674735185745446*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "BenderWu"}]], "Input",
 CellChangeTimes->{{3.674456508777961*^9, 3.674456512848606*^9}}],

Cell[BoxData[
 StyleBox["\<\"BenderWu function version 1.0. For bug report and suggestions, \
please contact Tin Sulejmanpasic at tin.sulejmanpasic@gmail.com\\n\\nThe \
BenderWu function calculates the solution of the differential \
equation\\n\\n-(1/2)\[Psi]''(x)+1/g^2 \*SubscriptBox[V, \
0](gx)\[Psi](x)+\*SubscriptBox[V, 2](gx)\[Psi](x)=\[Epsilon]\[Psi](x)\\n\\nas \
a parturbation series in the coupling g, \
i.e.\\n\\n\[Psi](x)=\!\(\\n\*UnderoverscriptBox[\(\[Sum]\), \(l = 0\), \(\
\[Infinity]\)]\(\\n\*SuperscriptBox[\\nSubscriptBox[\(A\), \(l\)], \(k\)] \\n\
\*SuperscriptBox[\(x\), \(k\)] \\n\*SuperscriptBox[\(g\), \(l\)]\)\) ,       \
\[Epsilon] = \!\(\\n\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\[Infinity]\
\)]\\n\*SubscriptBox[\(\[Epsilon]\), \(2  n\)]\)\\n\\nNotice that the \
expansion of \[Epsilon] is only in powers of g^2. \\n\\nThe call to the \
function BenderWu has the following syntax\\n\\nBenderWu[{\*SubscriptBox[V, \
\(0\)][x],\(\*SubscriptBox[V, \(2\)][x]},x,\[Nu],\*SubscriptBox[n, \
\(max\)],Options]\\n\\nor \\n\\nBenderWu[Subscript[V, \
0][x],x,\[Nu],\*SubscriptBox[n,max],Options] (for \*SubscriptBox[V, \
2][x]=0)\\n\\nThe respectivelly specify the potentials \*SubscriptBox[V, \
\(0\)][x] and \*SubscriptBox[V, \(2\)][x], the argument of th epotential (x \
in this case), the harmonic oscillator level number \[Nu], the maximal order \
of g^2 and a number of options (see below)\\n\\nIf called without any \
visualisation options, the function BenderWu returns a list of three \
elements. The first element gives a list of the perturbative corrections \
\*SubscriptBox[\[Epsilon], \(2  n\)]\\n\\n{\*SubscriptBox[\[Epsilon], \
0],\*SubscriptBox[\[Epsilon], 2],\*SubscriptBox[\[Epsilon], 4],..., \
\*SubscriptBox[\[Epsilon], \(2\*SubscriptBox[n,max]\)]}\\n\\nThe second \
element returns a matrix\\n\\n\*SuperscriptBox[SubscriptBox[A, \(l\)], \
\(k\)],      l=0,1,...,2*n_max, k=0,1,...,\[Nu]+3*(2*n_max)\\n\\nwhile the \
third element returns a list of four elements required for processing by the \
function BWProcess.\\n\\nOptions and their possible values are (default value \
listed first): \\nEvaluation->\\\"Analytical\\\", Evaluation->\\\"Numerical\\\
\",\\nWorkingPrecision->MachinePrecision (The working precision if the \
Evaluation is \\\"Numerical\\\")\\nCoupling->g (A symbol to be used for \
coupling in output)\\nMonitor->True,Monitor->False (Enable or disable the \
computation monitor) \\nSimplify->False,Simplify->True (Simplify the \
expressions at intermediate steps - Turning this on may speed up analytic \
evaluations)\\nMaxTime->Infinity, (time in seconds allowed for a single order \
computation.)\\nTotalMaxTime->Infinity, (time in minutes allowed to generate \
the series.)\\n\\nThe BenderWu function calles the function BWProcess to \
generate the output, and therefore it also takes in options shared by the \
function BWProcess. These are called the visaulisation options.\\n\\nOutput->\
\\\"BWProcess\\\", Output->\\\"Energy\\\" (output energy), \
Output->\\\"WaveFunction\\\" (output \
wave-function)\\nOutputStyle->\\\"Array\\\", OutputStyle->\\\"Series\\\" \
(display the output as a series in the coupling), OutputStyle->\\\"MatrixForm\
\\\" (display output as a matrix),\\nSeriesOutput->\\\"Coupling\\\" (group \
coupling in wave-function) ,SeriesOutput->\\\"Argument\\\" (group powers of \
argument x in wave-function)\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6814484546689873`*^9},
 CellTags->"Info23681459254-2592033"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "We will assume that the classical potential is given in a form\n\n\t\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["g", "2"]], 
    RowBox[{"V", "(", "xg", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\[LineSeparator]\[LineSeparator]And has at least a local minimum at x=0."
}], "Chapter",
 CellChangeTimes->{{3.677165115506937*^9, 3.6771653649559717`*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 1: The the double well potential", \
"Subchapter"]], "Subchapter",
 CellChangeTimes->{{3.674456518590372*^9, 3.6744565705023813`*^9}, {
   3.6744566134388323`*^9, 3.674456632424103*^9}, {3.674628982218484*^9, 
   3.674628982952627*^9}, {3.675158894735302*^9, 3.675158895658161*^9}, 
   3.677163741406467*^9, {3.677164515194133*^9, 3.677164522030615*^9}, {
   3.677165047856447*^9, 3.67716505169965*^9}, {3.677165106060012*^9, 
   3.67716510690088*^9}, 3.677165384681151*^9, 3.677173899661827*^9}],

Cell[CellGroupData[{

Cell["Define the double well potential V-function", "Subsubsection",
 CellChangeTimes->{{3.6771653942008867`*^9, 3.677165403573111*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "^", "2"}], 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], "^", "2"}], "/", "2"}]}], "+", 
    "v0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6771654069753923`*^9, 3.677165419117023*^9}, {
  3.679048102893338*^9, 3.6790481380891027`*^9}, {3.679048394836182*^9, 
  3.679048395267117*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The code below executes the ",
 Cell[BoxData[
  FormBox[
   StyleBox["BenderWu",
    FontColor->GrayLevel[0]], TraditionalForm]]],
 " function and put raw data in the variable BW. nu varaible specifies the \
level number."
}], "Subsubsection",
 CellChangeTimes->{{3.677164039923335*^9, 3.67716407040104*^9}, {
   3.67717390475276*^9, 3.677173916355556*^9}, 3.6771746939918613`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"nu", "=", "3"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Energy", " ", "Level"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BW", "=", 
   RowBox[{"BenderWu", "[", 
    RowBox[{
     RowBox[{"V", "[", "x", "]"}], ",", "x", ",", "nu", ",", "20"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.674456541776813*^9, 3.674456609809635*^9}, {
   3.6744566419964247`*^9, 3.67445672119779*^9}, {3.6745717836815653`*^9, 
   3.6745718057380867`*^9}, {3.674571920201737*^9, 3.6745719209939613`*^9}, 
   3.674572291717622*^9, {3.674573567357727*^9, 3.674573574247699*^9}, {
   3.6745736251916018`*^9, 3.674573630006649*^9}, {3.674573804921875*^9, 
   3.674573828235012*^9}, {3.6746284986701612`*^9, 3.6746285327849827`*^9}, {
   3.674628854831999*^9, 3.674628889134074*^9}, 3.674628928097528*^9, {
   3.674629131821726*^9, 3.6746292297882147`*^9}, {3.674709778039485*^9, 
   3.674709793309373*^9}, {3.674710047438457*^9, 3.674710047975814*^9}, {
   3.674710152668708*^9, 3.6747101593174067`*^9}, {3.677163766369789*^9, 
   3.677163767632559*^9}, {3.677163814867134*^9, 3.677163815135921*^9}, {
   3.677163848472686*^9, 3.6771638486267967`*^9}, {3.677166110408333*^9, 
   3.6771661116025963`*^9}, {3.677173918974483*^9, 3.677173919038835*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use the function ",
 Cell[BoxData[
  FormBox[
   StyleBox["BWProcess",
    FontColor->GrayLevel[0]], TraditionalForm]]],
 " to output only the energy data as an array"
}], "Subsubsection",
 CellChangeTimes->{{3.677164087968932*^9, 3.677164138528081*^9}, {
   3.677164169925243*^9, 3.6771641720152884`*^9}, 3.677174683991604*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", "BW", "]"}]], "Input",
 CellChangeTimes->{{3.674710054031659*^9, 3.6747100815987883`*^9}, {
  3.6771641444588413`*^9, 3.677164184119565*^9}, {3.679048170123543*^9, 
  3.679048196064308*^9}, {3.679048239040783*^9, 3.679048261463167*^9}, {
  3.6790483911998587`*^9, 3.679048391321755*^9}, {3.679048596698176*^9, 
  3.679048596862019*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["7", "2"], ",", 
   RowBox[{"-", "37"}], ",", 
   RowBox[{"-", 
    FractionBox["1491", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["59093", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["12241551", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["737082015", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["98057313291", "16"]}], ",", 
   RowBox[{"-", 
    FractionBox["7012334006013", "16"]}], ",", 
   RowBox[{"-", 
    FractionBox["4243360720841991", "128"]}], ",", 
   RowBox[{"-", 
    FractionBox["335931992943105347", "128"]}], ",", 
   RowBox[{"-", 
    FractionBox["55265231314740872481", "256"]}], ",", 
   RowBox[{"-", 
    FractionBox["4698834575021549716107", "256"]}], ",", 
   RowBox[{"-", 
    FractionBox["1645441548002722329730899", "1024"]}], ",", 
   RowBox[{"-", 
    FractionBox["147890927911945654351413771", "1024"]}], ",", 
   RowBox[{"-", 
    FractionBox["27232109811023865594366851667", "2048"]}], ",", 
   RowBox[{"-", 
    FractionBox["2563785494310350238645032319165", "2048"]}], ",", 
   RowBox[{"-", 
    FractionBox["3943641526520734713757019966103159", "32768"]}], ",", 
   RowBox[{"-", 
    FractionBox["386742622144562337875428697265689931", "32768"]}], ",", 
   RowBox[{"-", 
    FractionBox["77311058438461050231170955948595640901", "65536"]}], ",", 
   RowBox[{"-", 
    FractionBox["7870739727478352768930513274119341176927", "65536"]}], ",", 
   RowBox[{"-", 
    FractionBox["3263033635307846155565853095487353698852065", "262144"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6792249881100407`*^9, 3.679225703560804*^9, 
  3.681448465442418*^9, 3.712403226864057*^9, 3.713082916715439*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Note that this, at the expense of recomputing the series, can also be done \
directly from the ",
 Cell[BoxData[
  FormBox["BenderWu", TraditionalForm]]],
 " function using the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["Output",
     FontFamily->"Helvetica",
     FontColor->RGBColor[0., 0., 0.]], 
    StyleBox[" ",
     FontFamily->"Helvetica",
     FontColor->RGBColor[0., 0., 0.]], 
    StyleBox["\[Rule]",
     FontFamily->"Helvetica",
     FontColor->RGBColor[0., 0., 0.]], 
    StyleBox[" ",
     FontColor->GrayLevel[0.5]], 
    StyleBox["\"\<Energy\>\"",
     FontColor->GrayLevel[0.5]]}], TraditionalForm]]],
 " option"
}], "Subsubsection",
 CellChangeTimes->{{3.6771667957178392`*^9, 3.6771668713479567`*^9}, 
   3.6771672536299763`*^9, {3.6771740269638987`*^9, 3.677174027630785*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BenderWu", "[", 
  RowBox[{
   RowBox[{"V", "[", "x", "]"}], ",", "x", ",", "nu", ",", "20", ",", 
   RowBox[{"Output", "\[Rule]", "\"\<Energy\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6771668402665043`*^9, 3.677166843615588*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["7", "2"], ",", 
   RowBox[{"-", "37"}], ",", 
   RowBox[{"-", 
    FractionBox["1491", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["59093", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["12241551", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["737082015", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["98057313291", "16"]}], ",", 
   RowBox[{"-", 
    FractionBox["7012334006013", "16"]}], ",", 
   RowBox[{"-", 
    FractionBox["4243360720841991", "128"]}], ",", 
   RowBox[{"-", 
    FractionBox["335931992943105347", "128"]}], ",", 
   RowBox[{"-", 
    FractionBox["55265231314740872481", "256"]}], ",", 
   RowBox[{"-", 
    FractionBox["4698834575021549716107", "256"]}], ",", 
   RowBox[{"-", 
    FractionBox["1645441548002722329730899", "1024"]}], ",", 
   RowBox[{"-", 
    FractionBox["147890927911945654351413771", "1024"]}], ",", 
   RowBox[{"-", 
    FractionBox["27232109811023865594366851667", "2048"]}], ",", 
   RowBox[{"-", 
    FractionBox["2563785494310350238645032319165", "2048"]}], ",", 
   RowBox[{"-", 
    FractionBox["3943641526520734713757019966103159", "32768"]}], ",", 
   RowBox[{"-", 
    FractionBox["386742622144562337875428697265689931", "32768"]}], ",", 
   RowBox[{"-", 
    FractionBox["77311058438461050231170955948595640901", "65536"]}], ",", 
   RowBox[{"-", 
    FractionBox["7870739727478352768930513274119341176927", "65536"]}], ",", 
   RowBox[{"-", 
    FractionBox["3263033635307846155565853095487353698852065", "262144"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.679224991406925*^9, 3.6792257062651176`*^9, 
  3.679226309679606*^9, 3.681448468918322*^9, 3.712403229786024*^9, 
  3.713082921811919*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "To output the energy data as a series in coupling g, use the option ",
 Cell[BoxData[
  FormBox[
   StyleBox["OutputStyle",
    FontColor->GrayLevel[0]], TraditionalForm]]],
 " (also works directly with the ",
 Cell[BoxData[
  FormBox[
   StyleBox["BenderWu",
    FontColor->GrayLevel[0]], TraditionalForm]]],
 " function)"
}], "Subsubsection",
 CellChangeTimes->{{3.6771641637909327`*^9, 3.677164213798408*^9}, {
  3.677164340860981*^9, 3.677164341496943*^9}, {3.677166878921541*^9, 
  3.6771668816827583`*^9}, {3.677167305683117*^9, 3.677167325019752*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6771642206396017`*^9, 3.677164224837611*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["7", "2"], "-", 
  RowBox[{"37", " ", 
   SuperscriptBox["g", "2"]}], "-", 
  FractionBox[
   RowBox[{"1491", " ", 
    SuperscriptBox["g", "4"]}], "2"], "-", 
  FractionBox[
   RowBox[{"59093", " ", 
    SuperscriptBox["g", "6"]}], "2"], "-", 
  FractionBox[
   RowBox[{"12241551", " ", 
    SuperscriptBox["g", "8"]}], "8"], "-", 
  FractionBox[
   RowBox[{"737082015", " ", 
    SuperscriptBox["g", "10"]}], "8"], "-", 
  FractionBox[
   RowBox[{"98057313291", " ", 
    SuperscriptBox["g", "12"]}], "16"], "-", 
  FractionBox[
   RowBox[{"7012334006013", " ", 
    SuperscriptBox["g", "14"]}], "16"], "-", 
  FractionBox[
   RowBox[{"4243360720841991", " ", 
    SuperscriptBox["g", "16"]}], "128"], "-", 
  FractionBox[
   RowBox[{"335931992943105347", " ", 
    SuperscriptBox["g", "18"]}], "128"], "-", 
  FractionBox[
   RowBox[{"55265231314740872481", " ", 
    SuperscriptBox["g", "20"]}], "256"], "-", 
  FractionBox[
   RowBox[{"4698834575021549716107", " ", 
    SuperscriptBox["g", "22"]}], "256"], "-", 
  FractionBox[
   RowBox[{"1645441548002722329730899", " ", 
    SuperscriptBox["g", "24"]}], "1024"], "-", 
  FractionBox[
   RowBox[{"147890927911945654351413771", " ", 
    SuperscriptBox["g", "26"]}], "1024"], "-", 
  FractionBox[
   RowBox[{"27232109811023865594366851667", " ", 
    SuperscriptBox["g", "28"]}], "2048"], "-", 
  FractionBox[
   RowBox[{"2563785494310350238645032319165", " ", 
    SuperscriptBox["g", "30"]}], "2048"], "-", 
  FractionBox[
   RowBox[{"3943641526520734713757019966103159", " ", 
    SuperscriptBox["g", "32"]}], "32768"], "-", 
  FractionBox[
   RowBox[{"386742622144562337875428697265689931", " ", 
    SuperscriptBox["g", "34"]}], "32768"], "-", 
  FractionBox[
   RowBox[{"77311058438461050231170955948595640901", " ", 
    SuperscriptBox["g", "36"]}], "65536"], "-", 
  FractionBox[
   RowBox[{"7870739727478352768930513274119341176927", " ", 
    SuperscriptBox["g", "38"]}], "65536"], "-", 
  FractionBox[
   RowBox[{"3263033635307846155565853095487353698852065", " ", 
    SuperscriptBox["g", "40"]}], "262144"]}]], "Output",
 CellChangeTimes->{3.679047703887631*^9, 3.679048651436123*^9, 
  3.679222439501402*^9, 3.679224993547826*^9, 3.679225707902858*^9, 
  3.679226311664693*^9, 3.6814484745003033`*^9, 3.71240323365934*^9, 
  3.713082925101758*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["or in a matrix form", "Subsubsection",
 CellChangeTimes->{{3.677164250352376*^9, 3.677164271134357*^9}, {
  3.677164343165831*^9, 3.6771643460678473`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<MatrixForm\>\""}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.6771642762102127`*^9, 3.677164278421471*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      SuperscriptBox["g", "2"], 
      SuperscriptBox["g", "4"], 
      SuperscriptBox["g", "6"], 
      SuperscriptBox["g", "8"], 
      SuperscriptBox["g", "10"], 
      SuperscriptBox["g", "12"], 
      SuperscriptBox["g", "14"], 
      SuperscriptBox["g", "16"], 
      SuperscriptBox["g", "18"], 
      SuperscriptBox["g", "20"], 
      SuperscriptBox["g", "22"], 
      SuperscriptBox["g", "24"], 
      SuperscriptBox["g", "26"], 
      SuperscriptBox["g", "28"], 
      SuperscriptBox["g", "30"], 
      SuperscriptBox["g", "32"], 
      SuperscriptBox["g", "34"], 
      SuperscriptBox["g", "36"], 
      SuperscriptBox["g", "38"], 
      SuperscriptBox["g", "40"]},
     {
      FractionBox["7", "2"], 
      RowBox[{"-", "37"}], 
      RowBox[{"-", 
       FractionBox["1491", "2"]}], 
      RowBox[{"-", 
       FractionBox["59093", "2"]}], 
      RowBox[{"-", 
       FractionBox["12241551", "8"]}], 
      RowBox[{"-", 
       FractionBox["737082015", "8"]}], 
      RowBox[{"-", 
       FractionBox["98057313291", "16"]}], 
      RowBox[{"-", 
       FractionBox["7012334006013", "16"]}], 
      RowBox[{"-", 
       FractionBox["4243360720841991", "128"]}], 
      RowBox[{"-", 
       FractionBox["335931992943105347", "128"]}], 
      RowBox[{"-", 
       FractionBox["55265231314740872481", "256"]}], 
      RowBox[{"-", 
       FractionBox["4698834575021549716107", "256"]}], 
      RowBox[{"-", 
       FractionBox["1645441548002722329730899", "1024"]}], 
      RowBox[{"-", 
       FractionBox["147890927911945654351413771", "1024"]}], 
      RowBox[{"-", 
       FractionBox["27232109811023865594366851667", "2048"]}], 
      RowBox[{"-", 
       FractionBox["2563785494310350238645032319165", "2048"]}], 
      RowBox[{"-", 
       FractionBox["3943641526520734713757019966103159", "32768"]}], 
      RowBox[{"-", 
       FractionBox["386742622144562337875428697265689931", "32768"]}], 
      RowBox[{"-", 
       FractionBox["77311058438461050231170955948595640901", "65536"]}], 
      RowBox[{"-", 
       FractionBox["7870739727478352768930513274119341176927", "65536"]}], 
      RowBox[{"-", 
       FractionBox["3263033635307846155565853095487353698852065", 
        "262144"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.679047709685157*^9, 3.679048653378171*^9, 
  3.679222443006359*^9, 3.679224996099511*^9, 3.6792257102084*^9, 
  3.6792263147063217`*^9, 3.681448477044375*^9, 3.712403236455329*^9, 
  3.713082928095014*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "To change the symbol for the expansion one can use the option ",
 Cell[BoxData[
  FormBox[
   StyleBox["Coupling",
    FontColor->RGBColor[0., 0., 0.]], TraditionalForm]]],
 " "
}], "Subsubsection",
 CellChangeTimes->{{3.677164293571211*^9, 3.677164332767733*^9}, {
  3.6771650197144747`*^9, 3.6771650355485353`*^9}, {3.67716688535653*^9, 
  3.6771668882625628`*^9}, {3.677167009622958*^9, 3.677167009623067*^9}, {
  3.677167077748785*^9, 3.677167112515151*^9}, {3.677167168693508*^9, 
  3.6771671732081013`*^9}, {3.677167339971725*^9, 3.677167342042861*^9}, {
  3.679049128856687*^9, 3.679049213912079*^9}, {3.679049247111718*^9, 
  3.679049253774179*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"BWProcess", "[", 
   RowBox[{"BW", ",", 
    RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}], ",", 
    RowBox[{"Coupling", "\[Rule]", 
     RowBox[{"Sqrt", "[", "\[HBar]", "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.677164311963808*^9, 3.6771643218360367`*^9}, {
  3.67716464660384*^9, 3.6771646615129013`*^9}, {3.677164993462425*^9, 
  3.677165006773437*^9}, {3.679049217148649*^9, 3.679049245284141*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["7", "2"], "-", 
  RowBox[{"37", " ", "\[HBar]"}], "-", 
  FractionBox[
   RowBox[{"1491", " ", 
    SuperscriptBox["\[HBar]", "2"]}], "2"], "-", 
  FractionBox[
   RowBox[{"59093", " ", 
    SuperscriptBox["\[HBar]", "3"]}], "2"], "-", 
  FractionBox[
   RowBox[{"12241551", " ", 
    SuperscriptBox["\[HBar]", "4"]}], "8"], "-", 
  FractionBox[
   RowBox[{"737082015", " ", 
    SuperscriptBox["\[HBar]", "5"]}], "8"], "-", 
  FractionBox[
   RowBox[{"98057313291", " ", 
    SuperscriptBox["\[HBar]", "6"]}], "16"], "-", 
  FractionBox[
   RowBox[{"7012334006013", " ", 
    SuperscriptBox["\[HBar]", "7"]}], "16"], "-", 
  FractionBox[
   RowBox[{"4243360720841991", " ", 
    SuperscriptBox["\[HBar]", "8"]}], "128"], "-", 
  FractionBox[
   RowBox[{"335931992943105347", " ", 
    SuperscriptBox["\[HBar]", "9"]}], "128"], "-", 
  FractionBox[
   RowBox[{"55265231314740872481", " ", 
    SuperscriptBox["\[HBar]", "10"]}], "256"], "-", 
  FractionBox[
   RowBox[{"4698834575021549716107", " ", 
    SuperscriptBox["\[HBar]", "11"]}], "256"], "-", 
  FractionBox[
   RowBox[{"1645441548002722329730899", " ", 
    SuperscriptBox["\[HBar]", "12"]}], "1024"], "-", 
  FractionBox[
   RowBox[{"147890927911945654351413771", " ", 
    SuperscriptBox["\[HBar]", "13"]}], "1024"], "-", 
  FractionBox[
   RowBox[{"27232109811023865594366851667", " ", 
    SuperscriptBox["\[HBar]", "14"]}], "2048"], "-", 
  FractionBox[
   RowBox[{"2563785494310350238645032319165", " ", 
    SuperscriptBox["\[HBar]", "15"]}], "2048"], "-", 
  FractionBox[
   RowBox[{"3943641526520734713757019966103159", " ", 
    SuperscriptBox["\[HBar]", "16"]}], "32768"], "-", 
  FractionBox[
   RowBox[{"386742622144562337875428697265689931", " ", 
    SuperscriptBox["\[HBar]", "17"]}], "32768"], "-", 
  FractionBox[
   RowBox[{"77311058438461050231170955948595640901", " ", 
    SuperscriptBox["\[HBar]", "18"]}], "65536"], "-", 
  FractionBox[
   RowBox[{"7870739727478352768930513274119341176927", " ", 
    SuperscriptBox["\[HBar]", "19"]}], "65536"], "-", 
  FractionBox[
   RowBox[{"3263033635307846155565853095487353698852065", " ", 
    SuperscriptBox["\[HBar]", "20"]}], "262144"]}]], "Output",
 CellChangeTimes->{3.6790477145736628`*^9, 3.679048655670185*^9, 
  3.679049219167264*^9, 3.679049256769969*^9, 3.679222445469335*^9, 
  3.679224999217724*^9, 3.679225712268957*^9, 3.679226316781189*^9, 
  3.681448479330513*^9, 3.7124032388085012`*^9, 3.7130829302328033`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
For large orders, however, the output tends to be lengthy. For example, if we \
compute the 50 orders of the perturbation theory\
\>", "Subsubsection",
 CellChangeTimes->{{3.67922529804926*^9, 3.6792253454425898`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"nu", "=", "0"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Energy", " ", "Level"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BW", "=", 
   RowBox[{"BenderWu", "[", 
    RowBox[{
     RowBox[{"V", "[", "x", "]"}], ",", "x", ",", "nu", ",", "50"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.679225319918881*^9, 3.679225319997158*^9}, {
  3.679225389373917*^9, 3.679225389581534*^9}, {3.679225462467011*^9, 
  3.679225482842396*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "we can use the option ",
 Cell[BoxData[
  FormBox[
   StyleBox["Order",
    FontColor->GrayLevel[0]], TraditionalForm]]],
 " to truncate to a specific order "
}], "Subsubsection",
 CellChangeTimes->{{3.6771644844514503`*^9, 3.677164509441011*^9}, 
   3.677167362690446*^9, {3.679225350470625*^9, 3.679225352090479*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Order", "\[Rule]", "6"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.677164497620905*^9, 3.6771645030533752`*^9}, {
   3.6771645927351437`*^9, 3.677164594122102*^9}, {3.6771654776508427`*^9, 
   3.677165481939869*^9}, 3.679048918884529*^9, {3.679225358707108*^9, 
   3.6792253612140713`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", 
    FractionBox["9", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["89", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["5013", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["88251", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["3662169", "16"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.712403295056383*^9, 3.713082943101982*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "By using a list of two elements in the option ",
 Cell[BoxData[
  FormBox[
   StyleBox["Order",
    FontColor->GrayLevel[0]], TraditionalForm]]],
 ", an lower order can be specified "
}], "Subsubsection",
 CellChangeTimes->{{3.6771644844514503`*^9, 3.677164509441011*^9}, 
   3.677167362690446*^9, {3.679047739687111*^9, 3.679047810957712*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Order", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.679047767557644*^9, 3.679047767564148*^9}, {
   3.6790478137744303`*^9, 3.679047832784457*^9}, 3.6790489260543137`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["9", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["89", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["5013", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["88251", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["3662169", "16"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6790478156856127`*^9, 3.679047833951242*^9}, 
   3.679048659645989*^9, 3.6790488666315117`*^9, 3.679048926687581*^9, 
   3.6792224497461042`*^9, 3.679225004837406*^9, 3.6792253634203377`*^9, 
   3.679225435150715*^9, {3.6792254751439743`*^9, 3.6792254888641653`*^9}, 
   3.6792257367165813`*^9, 3.6792263255207863`*^9, 3.681448494090383*^9, 
   3.71240329984671*^9, 3.713082945200526*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "By default, the classical shift is ommited from the output and  formally \
corresponds to the order -1 (order zero is the harmonic oscillator \
contribution). Using the ",
 Cell[BoxData[
  FormBox[
   StyleBox["Order",
    FontColor->GrayLevel[0]], TraditionalForm]]],
 " option one can output this classical shift "
}], "Subsubsection",
 CellChangeTimes->{{3.6771644844514503`*^9, 3.677164509441011*^9}, 
   3.677167362690446*^9, {3.679047739687111*^9, 3.679047810957712*^9}, {
   3.6790486769012938`*^9, 3.679048849991235*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Order", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "6"}], "}"}]}], ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<MatrixForm\>\""}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.679047767557644*^9, 3.679047767564148*^9}, {
   3.6790478137744303`*^9, 3.679047832784457*^9}, {3.679048795510667*^9, 
   3.679048796019889*^9}, 3.679048882868853*^9, {3.679048938471751*^9, 
   3.679048956625132*^9}, {3.679049291697175*^9, 3.679049298643003*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", 
       SuperscriptBox["g", "2"]], "1", 
      SuperscriptBox["g", "2"], 
      SuperscriptBox["g", "4"], 
      SuperscriptBox["g", "6"], 
      SuperscriptBox["g", "8"], 
      SuperscriptBox["g", "10"], 
      SuperscriptBox["g", "12"]},
     {"v0", 
      FractionBox["1", "2"], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       FractionBox["9", "2"]}], 
      RowBox[{"-", 
       FractionBox["89", "2"]}], 
      RowBox[{"-", 
       FractionBox["5013", "8"]}], 
      RowBox[{"-", 
       FractionBox["88251", "8"]}], 
      RowBox[{"-", 
       FractionBox["3662169", "16"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.67904885178627*^9, 3.679048883712425*^9}, {
   3.679048928825961*^9, 3.6790489573533773`*^9}, 3.679049298981715*^9, 
   3.679222451299658*^9, 3.679225007712269*^9, 3.67922536566341*^9, 
   3.679225436589871*^9, {3.6792254768288183`*^9, 3.679225490980859*^9}, 
   3.679225739756844*^9, 3.679226328179604*^9, 3.681448496295224*^9, 
   3.7124033021181726`*^9, 3.71308294715897*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox["\"\<MatrixForm\>\"", TraditionalForm]]],
 " Output Style shows explicitly the dependence on the coupling"
}], "Subsubsection",
 CellChangeTimes->{{3.67904903174638*^9, 3.679049068021717*^9}, {
  3.679225135491805*^9, 3.679225142988996*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "The ",
 StyleBox["BWProcess",
  FontColor->GrayLevel[0]],
 " as well as ",
 StyleBox["BWProcess",
  FontColor->GrayLevel[0]],
 " function also has an option to output energy correction ratios, to quickly \
establish whether the series is factorial"
}], "Subsubsection",
 CellChangeTimes->{
  3.6792251502334843`*^9, {3.679225231619871*^9, 3.6792252344250517`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ratio", "=", 
   RowBox[{"BWProcess", "[", 
    RowBox[{"BW", ",", 
     RowBox[{"OutputStyle", "\[Rule]", "\"\<Ratio\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ratio", "//", "N"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "ratio", "]"}]}], "Input",
 CellChangeTimes->{{3.679225155106256*^9, 3.679225199938817*^9}, {
  3.681448510632695*^9, 3.681448541119523*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2.`"}], ",", "4.5`", ",", "9.88888888888889`", ",", 
   "14.081460674157304`", ",", "17.604428485936566`", ",", 
   "20.74859774960057`", ",", "23.679117211685206`", ",", 
   "26.49529428821217`", ",", "29.258854979975283`", ",", 
   "32.008217904139514`", ",", "34.76644183673689`", ",", "37.5461619529137`",
    ",", "40.35297798174138`", ",", "43.18793237434385`", ",", 
   "46.0493501665632`", ",", "48.934166725217956`", ",", "51.83882804660446`",
    ",", "54.75984614856875`", ",", "57.694095468039514`", ",", 
   "60.63893183593148`", ",", "63.59220266989247`", ",", "66.55219973001952`",
    ",", "69.51758869444404`", ",", "72.4873357831315`", ",", 
   "75.46064163822606`", ",", "78.43688633481555`", ",", "81.41558586926025`",
    ",", "84.39635881327311`", ",", "87.3789012653308`", ",", 
   "90.36296824531196`", ",", "93.34835993690795`", ",", "96.33491150652723`",
    ",", "99.32248553194972`", ",", "102.31096632689516`", ",", 
   "105.30025564387142`", ",", "108.29026938366603`", ",", 
   "111.28093504567552`", ",", "114.27218972877529`", ",", 
   "117.26397854584735`", ",", "120.25625335276449`", ",", 
   "123.24897171924957`", ",", "126.2420960879292`", ",", 
   "129.2355930814228`", ",", "132.2294329270708`", ",", 
   "135.22358897603235`", ",", "138.21803729874117`", ",", 
   "141.21275634263694`", ",", "144.2077266410522`", ",", 
   "147.20293056439982`", ",", "150.19835210654963`"}], "}"}]], "Output",
 CellChangeTimes->{{3.679225177796791*^9, 3.679225200260722*^9}, 
   3.6792253680588493`*^9, 3.6792254196652*^9, {3.6792254785987062`*^9, 
   3.679225492453497*^9}, 3.679225742811315*^9, 3.679226114175909*^9, 
   3.6792263304070587`*^9, {3.681448498502081*^9, 3.681448541473268*^9}, 
   3.712403304421255*^9, 3.7130829580624523`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw10F1I01EcxvF/ESM1Y5lRrZVW5rLWmC+5Wq09e990qH81Zy5Xm6VCgiSx
tYQ1TBiDStQLh96EMymsLipR8CKptQWrJLKxGeVNW8kuesObEZGx3w4cnvPh
e3f22rrrL65nGKZs7f7f9Pkhp8c8LdKTR7sRPfzQZX5oP5mLj4uTldMlQnI+
jJ9V7+dGS8k7ELxQxJt4VkHm40lT8Z2lhxJyIdiAYizskpL34Wb7CqtWyshF
ePA8qM9dB3IxeN6CAM+mIB/EXLZn/NtLJfkQQl+SVtERNVmI2g8bDm/2acgi
2GfLd7EcHVkMw4o9OOTQk0uxe/D+jCVpIJchf1OvX2mtJpcjOxDeE40ayRVw
xKb7X7E15KOwxXONb8K15Eos1HtlJn8dWYJ7S43CQitLPgbeo64+cUE9+Tgi
Ea6g91PGUng5vF+rYw3kEwgYnKu+lkbySbAF5p+tO0+TZRiY356URzM+BVew
ZFk60kSWo4N7zVPdZCIDU/Epcfe25rTdALfKPOpfJDNr/5xTu5wYPkNdgesz
PW2ShhbqSuRczQoO55mpK9Fn+RNJvSMzKnTGHLcvDZ6lroK/TsOJ17VSV6Oq
w36lnWuhrsbQ762C7wtkRoOarBG3a+AcdQ3+9rpTXsF56lqMv569YfKQ3Vq8
cG6ZEHzNdB1iXeaSlNZKXYdbT9sSbyfJjB5OqenxXY6Nuh4+kazT1U5mDDhg
6k80B234B8vfxgE=
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 50.}, {-2., 150.1983521065496}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.679225177796791*^9, 3.679225200260722*^9}, 
   3.6792253680588493`*^9, 3.6792254196652*^9, {3.6792254785987062`*^9, 
   3.679225492453497*^9}, 3.679225742811315*^9, 3.679226114175909*^9, 
   3.6792263304070587`*^9, {3.681448498502081*^9, 3.681448541473268*^9}, 
   3.712403304421255*^9, 3.713082958613173*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["To quickly plot the ratios the, one can use the syntax", "Subsubsection",
 CellChangeTimes->{{3.679225535527639*^9, 3.679225591521521*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<RatioPlot\>\""}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.679225584403809*^9, 3.679225584819766*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw10F1I01EcxvF/ESM1Y5lRrZVW5rLWmC+5Wq09e990qH81Zy5Xm6VCgiSx
tYQ1TBiDStQLh96EMymsLipR8CKptQWrJLKxGeVNW8kuesObEZGx3w4cnvPh
e3f22rrrL65nGKZs7f7f9Pkhp8c8LdKTR7sRPfzQZX5oP5mLj4uTldMlQnI+
jJ9V7+dGS8k7ELxQxJt4VkHm40lT8Z2lhxJyIdiAYizskpL34Wb7CqtWyshF
ePA8qM9dB3IxeN6CAM+mIB/EXLZn/NtLJfkQQl+SVtERNVmI2g8bDm/2acgi
2GfLd7EcHVkMw4o9OOTQk0uxe/D+jCVpIJchf1OvX2mtJpcjOxDeE40ayRVw
xKb7X7E15KOwxXONb8K15Eos1HtlJn8dWYJ7S43CQitLPgbeo64+cUE9+Tgi
Ea6g91PGUng5vF+rYw3kEwgYnKu+lkbySbAF5p+tO0+TZRiY356URzM+BVew
ZFk60kSWo4N7zVPdZCIDU/Epcfe25rTdALfKPOpfJDNr/5xTu5wYPkNdgesz
PW2ShhbqSuRczQoO55mpK9Fn+RNJvSMzKnTGHLcvDZ6lroK/TsOJ17VSV6Oq
w36lnWuhrsbQ762C7wtkRoOarBG3a+AcdQ3+9rpTXsF56lqMv569YfKQ3Vq8
cG6ZEHzNdB1iXeaSlNZKXYdbT9sSbyfJjB5OqenxXY6Nuh4+kazT1U5mDDhg
6k80B234B8vfxgE=
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 50.}, {-2., 150.1983521065496}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.679225581457597*^9, 3.679225593451927*^9}, 
   3.679225745107239*^9, 3.6792257982415657`*^9, 3.679226116403041*^9, 
   3.679226332424034*^9, 3.681448500711999*^9, 3.712403307638063*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "To display the wave-function data use the option ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["Output",
     FontColor->GrayLevel[0]], 
    StyleBox["->",
     FontColor->GrayLevel[0]], 
    StyleBox["\"\<WaveFunction\>\"",
     FontColor->GrayLevel[0.5]]}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.677164378118841*^9, 3.677164407145289*^9}, {
  3.6771673710542*^9, 3.677167379858555*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Output", "\[Rule]", "\"\<WaveFunction\>\""}], ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}], ",", 
   RowBox[{"Order", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.675157905177088*^9, 3.675157906599148*^9}, {
  3.6771644608354273`*^9, 3.677164470996359*^9}, {3.677164603229327*^9, 
  3.6771646308799953`*^9}, {3.677165483974875*^9, 3.677165484583468*^9}, {
  3.679047866355173*^9, 3.6790478721963787`*^9}, {3.679049266565527*^9, 
  3.679049271703042*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"g", " ", 
   RowBox[{"(", 
    RowBox[{"x", "+", 
     FractionBox[
      SuperscriptBox["x", "3"], "3"]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "18"], " ", 
   SuperscriptBox["g", "2"], " ", 
   SuperscriptBox["x", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"18", "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     SuperscriptBox["x", "4"]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["g", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "x"}], "+", 
     SuperscriptBox["x", "3"], "+", 
     FractionBox[
      SuperscriptBox["x", "5"], "3"], "+", 
     FractionBox[
      SuperscriptBox["x", "7"], "18"], "+", 
     FractionBox[
      SuperscriptBox["x", "9"], "162"]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["g", "4"], " ", 
    SuperscriptBox["x", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"8748", "+", 
      RowBox[{"3240", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"648", " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"108", " ", 
       SuperscriptBox["x", "6"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["x", "8"]}], "+", 
      SuperscriptBox["x", "10"]}], ")"}]}], "1944"], "+", 
  RowBox[{
   SuperscriptBox["g", "5"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"16", " ", "x"}], "+", 
     FractionBox[
      RowBox[{"15", " ", 
       SuperscriptBox["x", "3"]}], "2"], "+", 
     FractionBox[
      RowBox[{"5", " ", 
       SuperscriptBox["x", "5"]}], "2"], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["x", "7"]}], "9"], "+", 
     FractionBox[
      SuperscriptBox["x", "9"], "18"], "+", 
     FractionBox[
      SuperscriptBox["x", "11"], "162"], "+", 
     FractionBox[
      SuperscriptBox["x", "13"], "1944"], "+", 
     FractionBox[
      SuperscriptBox["x", "15"], "29160"]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["g", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"89", " ", 
       SuperscriptBox["x", "2"]}], "2"], "+", 
     FractionBox[
      RowBox[{"49", " ", 
       SuperscriptBox["x", "4"]}], "3"], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox["x", "6"]}], "2"], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox["x", "8"]}], "12"], "+", 
     FractionBox[
      RowBox[{"11", " ", 
       SuperscriptBox["x", "10"]}], "162"], "+", 
     FractionBox[
      SuperscriptBox["x", "12"], "162"], "+", 
     FractionBox[
      SuperscriptBox["x", "14"], "1944"], "+", 
     FractionBox[
      SuperscriptBox["x", "16"], "29160"], "+", 
     FractionBox[
      SuperscriptBox["x", "18"], "524880"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.6790478616742287`*^9, 3.6790478727415867`*^9}, 
   3.6790492810504847`*^9, 3.679049317024499*^9, 3.679222454490275*^9, 
   3.679225010432157*^9, 3.679225598272373*^9, 3.679225843104656*^9, 
   3.6792263377559147`*^9, 3.681448506755806*^9, 3.6814485612209167`*^9, 
   3.71240332040061*^9, 3.713082981240446*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "To change the grouping to the power of x use the ",
 StyleBox["SeriesOutput",
  FontColor->GrayLevel[0]],
 " option "
}], "Subsubsection",
 CellChangeTimes->{{3.677165492207074*^9, 3.677165530662528*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Output", "\[Rule]", "\"\<WaveFunction\>\""}], ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}], ",", 
   RowBox[{"Order", "\[Rule]", "3"}], ",", 
   RowBox[{"SeriesOutput", "\[Rule]", "\"\<Argument\>\""}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.677165536339939*^9, 3.677165543660872*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"g", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", "3"]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["g", "5"]}]}], ")"}], " ", "x"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["g", "2"], "+", 
     FractionBox[
      RowBox[{"9", " ", 
       SuperscriptBox["g", "4"]}], "2"], "+", 
     FractionBox[
      RowBox[{"89", " ", 
       SuperscriptBox["g", "6"]}], "2"]}], ")"}], " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["g", "3"], "+", 
     SuperscriptBox["g", "3"], "+", 
     FractionBox[
      RowBox[{"15", " ", 
       SuperscriptBox["g", "5"]}], "2"]}], ")"}], " ", 
   SuperscriptBox["x", "3"]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["g", "2"], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["g", "4"]}], "+", 
     RowBox[{"49", " ", 
      SuperscriptBox["g", "6"]}]}], ")"}], " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["g", "3"], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     RowBox[{"15", " ", 
      SuperscriptBox["g", "2"]}]}], ")"}], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{
   FractionBox["1", "18"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["g", "2"], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["g", "4"]}], "+", 
     RowBox[{"63", " ", 
      SuperscriptBox["g", "6"]}]}], ")"}], " ", 
   SuperscriptBox["x", "6"]}], "+", 
  RowBox[{
   FractionBox["1", "18"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["g", "3"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["g", "5"]}]}], ")"}], " ", 
   SuperscriptBox["x", "7"]}], "+", 
  RowBox[{
   FractionBox["1", "36"], " ", 
   SuperscriptBox["g", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     RowBox[{"21", " ", 
      SuperscriptBox["g", "2"]}]}], ")"}], " ", 
   SuperscriptBox["x", "8"]}], "+", 
  RowBox[{
   FractionBox["1", "162"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["g", "3"], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["g", "5"]}]}], ")"}], " ", 
   SuperscriptBox["x", "9"]}], "+", 
  RowBox[{
   FractionBox["1", "162"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["g", "4"], "+", 
     RowBox[{"11", " ", 
      SuperscriptBox["g", "6"]}]}], ")"}], " ", 
   SuperscriptBox["x", "10"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["g", "5"], " ", 
    SuperscriptBox["x", "11"]}], "162"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["g", "4"], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["g", "6"]}]}], ")"}], " ", 
    SuperscriptBox["x", "12"]}], "1944"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["g", "5"], " ", 
    SuperscriptBox["x", "13"]}], "1944"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["g", "6"], " ", 
    SuperscriptBox["x", "14"]}], "1944"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["g", "5"], " ", 
    SuperscriptBox["x", "15"]}], "29160"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["g", "6"], " ", 
    SuperscriptBox["x", "16"]}], "29160"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["g", "6"], " ", 
    SuperscriptBox["x", "18"]}], "524880"]}]], "Output",
 CellChangeTimes->{3.679047874956605*^9, 3.679049319153618*^9, 
  3.679222457130219*^9, 3.679225012450989*^9, 3.679225600736806*^9, 
  3.679225845347533*^9, 3.679226339593902*^9, 3.681448563044766*^9, 
  3.712403332305743*^9, 3.713082983794999*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "To include the pre-exponent use the option ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Prefactor", " ", "\[Rule]", "True"}], TraditionalForm]],
  FormatType->"TraditionalForm",
  FontColor->GrayLevel[0]]
}], "Subsubsection",
 CellChangeTimes->{{3.677165492207074*^9, 3.677165530662528*^9}, {
  3.713082816047455*^9, 3.7130828556756897`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Output", "\[Rule]", "\"\<WaveFunction\>\""}], ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<Series\>\""}], ",", 
   RowBox[{"Order", "\[Rule]", "3"}], ",", 
   RowBox[{"Prefactor", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.713082831998588*^9, 3.713082839202875*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["x", "2"], "2"]}]], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    RowBox[{"g", " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       FractionBox[
        SuperscriptBox["x", "3"], "3"]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "18"], " ", 
     SuperscriptBox["g", "2"], " ", 
     SuperscriptBox["x", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["x", "2"]}], "+", 
       SuperscriptBox["x", "4"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["g", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "x"}], "+", 
       SuperscriptBox["x", "3"], "+", 
       FractionBox[
        SuperscriptBox["x", "5"], "3"], "+", 
       FractionBox[
        SuperscriptBox["x", "7"], "18"], "+", 
       FractionBox[
        SuperscriptBox["x", "9"], "162"]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["g", "4"], " ", 
      SuperscriptBox["x", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"8748", "+", 
        RowBox[{"3240", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"648", " ", 
         SuperscriptBox["x", "4"]}], "+", 
        RowBox[{"108", " ", 
         SuperscriptBox["x", "6"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["x", "8"]}], "+", 
        SuperscriptBox["x", "10"]}], ")"}]}], "1944"], "+", 
    RowBox[{
     SuperscriptBox["g", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"16", " ", "x"}], "+", 
       FractionBox[
        RowBox[{"15", " ", 
         SuperscriptBox["x", "3"]}], "2"], "+", 
       FractionBox[
        RowBox[{"5", " ", 
         SuperscriptBox["x", "5"]}], "2"], "+", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["x", "7"]}], "9"], "+", 
       FractionBox[
        SuperscriptBox["x", "9"], "18"], "+", 
       FractionBox[
        SuperscriptBox["x", "11"], "162"], "+", 
       FractionBox[
        SuperscriptBox["x", "13"], "1944"], "+", 
       FractionBox[
        SuperscriptBox["x", "15"], "29160"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["g", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"89", " ", 
         SuperscriptBox["x", "2"]}], "2"], "+", 
       FractionBox[
        RowBox[{"49", " ", 
         SuperscriptBox["x", "4"]}], "3"], "+", 
       FractionBox[
        RowBox[{"7", " ", 
         SuperscriptBox["x", "6"]}], "2"], "+", 
       FractionBox[
        RowBox[{"7", " ", 
         SuperscriptBox["x", "8"]}], "12"], "+", 
       FractionBox[
        RowBox[{"11", " ", 
         SuperscriptBox["x", "10"]}], "162"], "+", 
       FractionBox[
        SuperscriptBox["x", "12"], "162"], "+", 
       FractionBox[
        SuperscriptBox["x", "14"], "1944"], "+", 
       FractionBox[
        SuperscriptBox["x", "16"], "29160"], "+", 
       FractionBox[
        SuperscriptBox["x", "18"], "524880"]}], ")"}]}]}], ")"}]}]], "Output",\

 CellChangeTimes->{3.713082985947057*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "To output the coefficients of the wave function as a matrix use ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["OutputStyle",
     FontColor->GrayLevel[0]], 
    StyleBox["\[Rule]",
     FontColor->GrayLevel[0]], 
    StyleBox["\"\<MatrixForm\>\"",
     FontColor->GrayLevel[0.5]]}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.6771655848798923`*^9, 3.6771656312042522`*^9}, {
  3.677167414100876*^9, 3.677167422035287*^9}, {3.67717465820673*^9, 
  3.677174660257545*^9}, {3.678005415159176*^9, 3.678005429131321*^9}, {
  3.7124033399171658`*^9, 3.712403341114511*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Output", "\[Rule]", "\"\<WaveFunction\>\""}], ",", 
   RowBox[{"OutputStyle", "\[Rule]", "\"\<MatrixForm\>\""}], ",", 
   RowBox[{"Order", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.674710753683477*^9, 3.674710756641577*^9}, {
  3.677165614893488*^9, 3.6771656419928017`*^9}, {3.6771660799018087`*^9, 
  3.6771660982610273`*^9}, {3.677167218833127*^9, 3.677167218982518*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\<\" \"\>", "1", "x", 
      SuperscriptBox["x", "2"], 
      SuperscriptBox["x", "3"], 
      SuperscriptBox["x", "4"], 
      SuperscriptBox["x", "5"], 
      SuperscriptBox["x", "6"], 
      SuperscriptBox["x", "7"], 
      SuperscriptBox["x", "8"], 
      SuperscriptBox["x", "9"], 
      SuperscriptBox["x", "10"], 
      SuperscriptBox["x", "11"], 
      SuperscriptBox["x", "12"], 
      SuperscriptBox["x", "13"], 
      SuperscriptBox["x", "14"], 
      SuperscriptBox["x", "15"], 
      SuperscriptBox["x", "16"], 
      SuperscriptBox["x", "17"], 
      SuperscriptBox["x", "18"]},
     {"1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0"},
     {"g", "0", "1", "0", 
      FractionBox["1", "3"], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
       "0", "0", "0", "0", "0"},
     {
      SuperscriptBox["g", "2"], "0", "0", "1", "0", 
      FractionBox["1", "3"], "0", 
      FractionBox["1", "18"], "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0"},
     {
      SuperscriptBox["g", "3"], "0", "2", "0", "1", "0", 
      FractionBox["1", "3"], "0", 
      FractionBox["1", "18"], "0", 
      FractionBox["1", "162"], "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {
      SuperscriptBox["g", "4"], "0", "0", 
      FractionBox["9", "2"], "0", 
      FractionBox["5", "3"], "0", 
      FractionBox["1", "3"], "0", 
      FractionBox["1", "18"], "0", 
      FractionBox["1", "162"], "0", 
      FractionBox["1", "1944"], "0", "0", "0", "0", "0", "0"},
     {
      SuperscriptBox["g", "5"], "0", "16", "0", 
      FractionBox["15", "2"], "0", 
      FractionBox["5", "2"], "0", 
      FractionBox["4", "9"], "0", 
      FractionBox["1", "18"], "0", 
      FractionBox["1", "162"], "0", 
      FractionBox["1", "1944"], "0", 
      FractionBox["1", "29160"], "0", "0", "0"},
     {
      SuperscriptBox["g", "6"], "0", "0", 
      FractionBox["89", "2"], "0", 
      FractionBox["49", "3"], "0", 
      FractionBox["7", "2"], "0", 
      FractionBox["7", "12"], "0", 
      FractionBox["11", "162"], "0", 
      FractionBox["1", "162"], "0", 
      FractionBox["1", "1944"], "0", 
      FractionBox["1", "29160"], "0", 
      FractionBox["1", "524880"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6790478772043953`*^9, 3.6790493210812483`*^9, 
  3.67922246027173*^9, 3.679225014414822*^9, 3.679225603067032*^9, 
  3.679225890300617*^9, 3.679226341686054*^9, 3.681448565039657*^9, 
  3.7124033431797457`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Finally note that the Output and OutputStyle options can be called directly \
from the ",
 Cell[BoxData[
  FormBox["BenderWu", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " function"
}], "Subsubsection",
 CellChangeTimes->{{3.6771667372102003`*^9, 3.6771667637236357`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2: The SUSY double well ground state", "Subchapter",
 CellChangeTimes->{{3.674456749487309*^9, 3.6744567716994333`*^9}}],

Cell[TextData[{
 "The SUSY potential is given in the form\n\t\t",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"W", "'"}], " ", 
      RowBox[{
       RowBox[{"(", "x", ")"}], "^", "2"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"W", "''"}], 
      RowBox[{"(", "x", ")"}]}]}],
    FontColor->GrayLevel[0]], TraditionalForm]]],
 "\nWe take\n\t\t",
 Cell[BoxData[{
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"W", "'"}], 
      RowBox[{"(", "x", ")"}]}], "=", 
     RowBox[{
      FractionBox["1", "g"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", "xg", ")"}], "2"], "-", "1"}], ")"}]}]}],
    FontColor->GrayLevel[0]], TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"W", "''"}], 
      RowBox[{"(", "x", ")"}]}], "=", 
     RowBox[{"xg", "-", "1"}]}],
    FontColor->GrayLevel[0]], TraditionalForm]}]],
 "\nwhich is of the form\n\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"\t", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["g", "2"]], 
      RowBox[{"V", "(", "xg", ")"}]}], "+", 
     RowBox[{
      SubscriptBox["V", "f"], "(", "xg", ")"}]}]}], TraditionalForm]],
  FontColor->GrayLevel[0]],
 "\nTo imput this form into the ",
 Cell[BoxData[
  FormBox["BenderWu", TraditionalForm]]],
 " function we use put ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{"V", "[", "x", "]"}], ",", 
      RowBox[{
       SubscriptBox["V", "f"], "[", "x", "]"}]}], "}"}],
    FontColor->GrayLevel[0]], TraditionalForm]]],
 " as the first argument."
}], "Subsubsection",
 CellChangeTimes->{{3.677166183555922*^9, 3.677166443151935*^9}, {
  3.677166482678899*^9, 3.6771665377935143`*^9}, {3.6771666509835157`*^9, 
  3.6771666511277037`*^9}, {3.6771667015542803`*^9, 3.677166701554421*^9}, {
  3.677167453350873*^9, 3.677167453629747*^9}, {3.6771746392012787`*^9, 
  3.6771746402283983`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Define the ",
 Cell[BoxData[
  FormBox["V", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "f"], TraditionalForm]]],
 " functions:"
}], "Subsubsection",
 CellChangeTimes->{{3.677166140535359*^9, 3.677166156375661*^9}, {
   3.677166543660253*^9, 3.6771665534004793`*^9}, 3.677167468052321*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"x", "^", "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", "1"}], ")"}], "^", "2"}], "/", "2"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Vf", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "x"}], "-", "1"}], ")"}], "/", "2"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.677166148321979*^9, 3.6771661721140623`*^9}, {
  3.67716655821566*^9, 3.677166573832206*^9}, {3.6771667042840157`*^9, 
  3.677166709192872*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute 50 orders of the ground state energy energy", "Subsubsection",
 CellChangeTimes->{{3.6771674601052227`*^9, 3.677167522330801*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BenderWu", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"V", "[", "x", "]"}], ",", 
     RowBox[{"Vf", "[", "x", "]"}]}], "}"}], ",", "x", ",", "0", ",", "50", 
   ",", 
   RowBox[{"Output", "\[Rule]", "\"\<Energy\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.674456782574746*^9, 3.674456949619382*^9}, {
  3.674459125027997*^9, 3.674459143641165*^9}, {3.674459203750058*^9, 
  3.674459312045835*^9}, {3.674459348125079*^9, 3.6744594101788073`*^9}, {
  3.674462547521594*^9, 3.674462547783545*^9}, {3.6744625820917473`*^9, 
  3.6744626410776*^9}, {3.67457231376096*^9, 3.674572366461216*^9}, {
  3.674572942561337*^9, 3.674572980291492*^9}, {3.67457322410789*^9, 
  3.674573231078128*^9}, {3.674573457775885*^9, 3.674573498498415*^9}, {
  3.6747116777270927`*^9, 3.674711678175756*^9}, {3.677166577388349*^9, 
  3.677166620769936*^9}, {3.677166721538974*^9, 3.6771667300459747`*^9}, {
  3.6771675251440363`*^9, 3.677167542180314*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6790493297371807`*^9, 3.679222470561266*^9, {3.679225905322176*^9, 
   3.67922591886451*^9}, {3.679226093006537*^9, 3.679226110990547*^9}, 
   3.6792263496177673`*^9, 3.681448573065175*^9, 3.712403351698029*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The higher states, however, are non-trivial and asymptotic", \
"Subsubsection",
 CellChangeTimes->{{3.679222481395924*^9, 3.679222511660963*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BenderWu", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"V", "[", "x", "]"}], ",", 
     RowBox[{"Vf", "[", "x", "]"}]}], "}"}], ",", "x", ",", "3", ",", "20", 
   ",", 
   RowBox[{"Output", "\[Rule]", "\"\<Energy\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6792224967075577`*^9, 3.679222504669775*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", 
   RowBox[{"-", "27"}], ",", 
   RowBox[{"-", 
    FractionBox["933", "2"]}], ",", 
   RowBox[{"-", "15930"}], ",", 
   RowBox[{"-", 
    FractionBox["5709819", "8"]}], ",", 
   RowBox[{"-", "37317456"}], ",", 
   RowBox[{"-", 
    FractionBox["34608454413", "16"]}], ",", 
   RowBox[{"-", "135233738865"}], ",", 
   RowBox[{"-", 
    FractionBox["1148257529423295", "128"]}], ",", 
   RowBox[{"-", 
    FractionBox["1249312299767073", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["11602630924217578995", "256"]}], ",", 
   RowBox[{"-", 
    FractionBox["13633884023815172565", "4"]}], ",", 
   RowBox[{"-", 
    FractionBox["271004060117471623396551", "1024"]}], ",", 
   RowBox[{"-", 
    FractionBox["42307664732550159904665", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["3556765769847577900845002685", "2048"]}], ",", 
   RowBox[{"-", 
    FractionBox["1169569650216830604041265435", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["412948117774135677254860661773671", "32768"]}], ",", 
   RowBox[{"-", 
    FractionBox["35560084125363913367681339412657", "32"]}], ",", 
   RowBox[{"-", 
    FractionBox["6564235839632953432885685601960166455", "65536"]}], ",", 
   RowBox[{"-", 
    FractionBox["590272360660759899837336354866516625", "64"]}], ",", 
   RowBox[{"-", 
    FractionBox["227341959472203789817641802700938876017573", "262144"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.679222500915248*^9, 3.6792225053745403`*^9}, 
   3.679225899380612*^9, 3.6792261215962877`*^9, 3.679226350001478*^9, 
   3.6814485754792356`*^9, 3.712403358540766*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use the option ",
 Cell[BoxData[
  FormBox["MaxTime", TraditionalForm]]],
 " to put a time constraint (in seconds) on the evaluation of a single order \
"
}], "Subsubsection",
 CellChangeTimes->{{3.677167559711047*^9, 3.67716763820721*^9}, {
  3.677167752655529*^9, 3.677167839449588*^9}, {3.677167933094281*^9, 
  3.677167936723762*^9}, {3.679049454031816*^9, 3.6790494797848387`*^9}, {
  3.679222571354639*^9, 3.6792225762867804`*^9}, {3.679226387913362*^9, 
  3.6792263924712963`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"BenderWu", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"V", "[", "x", "]"}], ",", 
      RowBox[{"Vf", "[", "x", "]"}]}], "}"}], ",", "x", ",", "3", ",", "50", 
    ",", 
    RowBox[{"Output", "\[Rule]", "\"\<Energy\>\""}], ",", 
    RowBox[{"MaxTime", "\[Rule]", ".02"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6751552685451736`*^9, 3.675155316025093*^9}, 
   3.677167510011278*^9, {3.6771675525453777`*^9, 3.677167603068376*^9}, {
   3.677167641681076*^9, 3.677167733506465*^9}, {3.677167798870872*^9, 
   3.677167802720079*^9}, {3.6771678417953787`*^9, 3.677167872381793*^9}, {
   3.677173836275614*^9, 3.677173836309205*^9}, {3.679049344856666*^9, 
   3.679049346931643*^9}, {3.679049406701779*^9, 3.6790494112164783`*^9}, {
   3.679226476018463*^9, 3.6792265589567842`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"WARNING: Time constraint for a single order exeeded \"\>", 
   "\[InvisibleSpace]", "0.02`", 
   "\[InvisibleSpace]", "\<\" seconds  at order \"\>", "\[InvisibleSpace]", 
   SuperscriptBox["g", "38"], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "WARNING: Time constraint for a single order exeeded ", 0.02, 
   " seconds  at order ", $CellContext`g^38, "."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.679226553164403*^9, 3.679226559642776*^9}, 
   3.681448580156205*^9, 3.7124033638367357`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Output generated to order \"\>", "\[InvisibleSpace]", 
   SuperscriptBox["g", "36"]}],
  SequenceForm["Output generated to order ", $CellContext`g^36],
  Editable->False]], "Print",
 CellChangeTimes->{{3.679226553164403*^9, 3.679226559642776*^9}, 
   3.681448580156205*^9, 3.712403363848074*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", 
   RowBox[{"-", "27"}], ",", 
   RowBox[{"-", 
    FractionBox["933", "2"]}], ",", 
   RowBox[{"-", "15930"}], ",", 
   RowBox[{"-", 
    FractionBox["5709819", "8"]}], ",", 
   RowBox[{"-", "37317456"}], ",", 
   RowBox[{"-", 
    FractionBox["34608454413", "16"]}], ",", 
   RowBox[{"-", "135233738865"}], ",", 
   RowBox[{"-", 
    FractionBox["1148257529423295", "128"]}], ",", 
   RowBox[{"-", 
    FractionBox["1249312299767073", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["11602630924217578995", "256"]}], ",", 
   RowBox[{"-", 
    FractionBox["13633884023815172565", "4"]}], ",", 
   RowBox[{"-", 
    FractionBox["271004060117471623396551", "1024"]}], ",", 
   RowBox[{"-", 
    FractionBox["42307664732550159904665", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["3556765769847577900845002685", "2048"]}], ",", 
   RowBox[{"-", 
    FractionBox["1169569650216830604041265435", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["412948117774135677254860661773671", "32768"]}], ",", 
   RowBox[{"-", 
    FractionBox["35560084125363913367681339412657", "32"]}], ",", 
   RowBox[{"-", 
    FractionBox["6564235839632953432885685601960166455", "65536"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.679226532972238*^9, 3.679226559691173*^9}, 
   3.6814485802224607`*^9, 3.712403363920231*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Alternativelly one can use the option ",
 Cell[BoxData[
  FormBox["TotalMaxTime", TraditionalForm]]],
 " to give a time constraint (in minutes) for the entire evaluation. "
}], "Subsubsection",
 CellChangeTimes->{{3.6771679150441217`*^9, 3.6771679594412107`*^9}, {
   3.679049485287951*^9, 3.679049491137773*^9}, {3.679222625412731*^9, 
   3.6792226282081127`*^9}, 3.681448607246358*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BenderWu", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"V", "[", "x", "]"}], ",", 
     RowBox[{"Vf", "[", "x", "]"}]}], "}"}], ",", "x", ",", "3", ",", "100", 
   ",", 
   RowBox[{"Output", "\[Rule]", "\"\<Energy\>\""}], ",", 
   RowBox[{"TotalMaxTime", "\[Rule]", ".005"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.677167967728169*^9, 3.6771679723695993`*^9}, {
  3.677173848804976*^9, 3.677173850064826*^9}, {3.679226514693255*^9, 
  3.679226523734988*^9}, {3.6792265664556932`*^9, 3.679226586270606*^9}, {
  3.681448601074421*^9, 3.681448601307925*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"WARNING: Time set to complete the evaluation \"\>", 
   "\[InvisibleSpace]", "0.005`", 
   "\[InvisibleSpace]", "\<\" minutes  was exceeded at order \"\>", 
   "\[InvisibleSpace]", 
   SuperscriptBox["g", "35"], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "WARNING: Time set to complete the evaluation ", 0.005, 
   " minutes  was exceeded at order ", $CellContext`g^35, "."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.67922658292276*^9, 3.679226587034131*^9}, {
   3.681448585200103*^9, 3.681448602301468*^9}, 3.712403371457266*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Output generated to order \"\>", "\[InvisibleSpace]", 
   SuperscriptBox["g", "34"]}],
  SequenceForm["Output generated to order ", $CellContext`g^34],
  Editable->False]], "Print",
 CellChangeTimes->{{3.67922658292276*^9, 3.679226587034131*^9}, {
   3.681448585200103*^9, 3.681448602301468*^9}, 3.712403371471613*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", 
   RowBox[{"-", "27"}], ",", 
   RowBox[{"-", 
    FractionBox["933", "2"]}], ",", 
   RowBox[{"-", "15930"}], ",", 
   RowBox[{"-", 
    FractionBox["5709819", "8"]}], ",", 
   RowBox[{"-", "37317456"}], ",", 
   RowBox[{"-", 
    FractionBox["34608454413", "16"]}], ",", 
   RowBox[{"-", "135233738865"}], ",", 
   RowBox[{"-", 
    FractionBox["1148257529423295", "128"]}], ",", 
   RowBox[{"-", 
    FractionBox["1249312299767073", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["11602630924217578995", "256"]}], ",", 
   RowBox[{"-", 
    FractionBox["13633884023815172565", "4"]}], ",", 
   RowBox[{"-", 
    FractionBox["271004060117471623396551", "1024"]}], ",", 
   RowBox[{"-", 
    FractionBox["42307664732550159904665", "2"]}], ",", 
   RowBox[{"-", 
    FractionBox["3556765769847577900845002685", "2048"]}], ",", 
   RowBox[{"-", 
    FractionBox["1169569650216830604041265435", "8"]}], ",", 
   RowBox[{"-", 
    FractionBox["412948117774135677254860661773671", "32768"]}], ",", 
   RowBox[{"-", 
    FractionBox["35560084125363913367681339412657", "32"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.679049410560936*^9, 3.679049450123063*^9, 3.679222638558728*^9, 
   3.67922618679268*^9, 3.679226388490724*^9, {3.679226516423876*^9, 
   3.6792265242610598`*^9}, {3.679226564005272*^9, 3.679226587084112*^9}, {
   3.6814485852561493`*^9, 3.681448602366654*^9}, 3.712403371560927*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Using a symbolic \[Zeta] parameter may give a very complicated output which \
takes long to evaluate, as each recursion step is not simplified. To improve \
this use the option ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Simplify", "\[Rule]", "True"}], TraditionalForm]]],
 " which simplifies the expression in each iteration."
}], "Subsubsection",
 CellChangeTimes->{{3.677167995930471*^9, 3.677168019955872*^9}, {
  3.677174079273869*^9, 3.677174100521386*^9}, {3.6792263977310266`*^9, 
  3.679226467164012*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"energyzet", "=", 
  RowBox[{"BenderWu", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "^", "2"}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", "1"}], ")"}], "^", "2"}], "/", "2"}]}], ",", 
       RowBox[{"\[Zeta]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "x"}], "-", "1"}], ")"}], "/", "2"}]}]}], "}"}], 
     "]"}], ",", "x", ",", "0", ",", "10", ",", 
    RowBox[{"Output", "\[Rule]", "\"\<Energy\>\""}], ",", 
    RowBox[{"Simplify", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.677168030795879*^9, 3.677168059367585*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], "-", 
    FractionBox["\[Zeta]", "2"]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{"3", " ", "\[Zeta]"}], "-", 
      SuperscriptBox["\[Zeta]", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["9", "2"]}], "+", 
    FractionBox[
     RowBox[{"35", " ", "\[Zeta]"}], "4"], "-", 
    FractionBox[
     RowBox[{"21", " ", 
      SuperscriptBox["\[Zeta]", "2"]}], "4"], "+", 
    SuperscriptBox["\[Zeta]", "3"]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "178"}], "+", 
      RowBox[{"417", " ", "\[Zeta]"}], "-", 
      RowBox[{"346", " ", 
       SuperscriptBox["\[Zeta]", "2"]}], "+", 
      RowBox[{"123", " ", 
       SuperscriptBox["\[Zeta]", "3"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["\[Zeta]", "4"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "10026"}], "+", 
      RowBox[{"27073", " ", "\[Zeta]"}], "-", 
      RowBox[{"27954", " ", 
       SuperscriptBox["\[Zeta]", "2"]}], "+", 
      RowBox[{"14024", " ", 
       SuperscriptBox["\[Zeta]", "3"]}], "-", 
      RowBox[{"3453", " ", 
       SuperscriptBox["\[Zeta]", "4"]}], "+", 
      RowBox[{"336", " ", 
       SuperscriptBox["\[Zeta]", "5"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "176502"}], "+", 
      RowBox[{"533199", " ", "\[Zeta]"}], "-", 
      RowBox[{"646826", " ", 
       SuperscriptBox["\[Zeta]", "2"]}], "+", 
      RowBox[{"409020", " ", 
       SuperscriptBox["\[Zeta]", "3"]}], "-", 
      RowBox[{"143456", " ", 
       SuperscriptBox["\[Zeta]", "4"]}], "+", 
      RowBox[{"26613", " ", 
       SuperscriptBox["\[Zeta]", "5"]}], "-", 
      RowBox[{"2048", " ", 
       SuperscriptBox["\[Zeta]", "6"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "7324338"}], "+", 
      RowBox[{"24225545", " ", "\[Zeta]"}], "-", 
      RowBox[{"33289620", " ", 
       SuperscriptBox["\[Zeta]", "2"]}], "+", 
      RowBox[{"24948118", " ", 
       SuperscriptBox["\[Zeta]", "3"]}], "-", 
      RowBox[{"11101560", " ", 
       SuperscriptBox["\[Zeta]", "4"]}], "+", 
      RowBox[{"2948880", " ", 
       SuperscriptBox["\[Zeta]", "5"]}], "-", 
      RowBox[{"434481", " ", 
       SuperscriptBox["\[Zeta]", "6"]}], "+", 
      RowBox[{"27456", " ", 
       SuperscriptBox["\[Zeta]", "7"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "173433858"}], "+", 
      RowBox[{"617898849", " ", "\[Zeta]"}], "-", 
      RowBox[{"937723070", " ", 
       SuperscriptBox["\[Zeta]", "2"]}], "+", 
      RowBox[{"801021747", " ", 
       SuperscriptBox["\[Zeta]", "3"]}], "-", 
      RowBox[{"424463408", " ", 
       SuperscriptBox["\[Zeta]", "4"]}], "+", 
      RowBox[{"143601633", " ", 
       SuperscriptBox["\[Zeta]", "5"]}], "-", 
      RowBox[{"30392576", " ", 
       SuperscriptBox["\[Zeta]", "6"]}], "+", 
      RowBox[{"3687291", " ", 
       SuperscriptBox["\[Zeta]", "7"]}], "-", 
      RowBox[{"196608", " ", 
       SuperscriptBox["\[Zeta]", "8"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "256"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "36761448858"}], "+", 
      RowBox[{"139291708325", " ", "\[Zeta]"}], "-", 
      RowBox[{"229136842452", " ", 
       SuperscriptBox["\[Zeta]", "2"]}], "+", 
      RowBox[{"217166228688", " ", 
       SuperscriptBox["\[Zeta]", "3"]}], "-", 
      RowBox[{"131641698510", " ", 
       SuperscriptBox["\[Zeta]", "4"]}], "+", 
      RowBox[{"53191108992", " ", 
       SuperscriptBox["\[Zeta]", "5"]}], "-", 
      RowBox[{"14373789276", " ", 
       SuperscriptBox["\[Zeta]", "6"]}], "+", 
      RowBox[{"2510382336", " ", 
       SuperscriptBox["\[Zeta]", "7"]}], "-", 
      RowBox[{"257473629", " ", 
       SuperscriptBox["\[Zeta]", "8"]}], "+", 
      RowBox[{"11824384", " ", 
       SuperscriptBox["\[Zeta]", "9"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "256"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1075597900990"}], "+", 
      RowBox[{"4290761956791", " ", "\[Zeta]"}], "-", 
      RowBox[{"7542533259788", " ", 
       SuperscriptBox["\[Zeta]", "2"]}], "+", 
      RowBox[{"7776060763308", " ", 
       SuperscriptBox["\[Zeta]", "3"]}], "-", 
      RowBox[{"5244386895094", " ", 
       SuperscriptBox["\[Zeta]", "4"]}], "+", 
      RowBox[{"2429616464076", " ", 
       SuperscriptBox["\[Zeta]", "5"]}], "-", 
      RowBox[{"785671502848", " ", 
       SuperscriptBox["\[Zeta]", "6"]}], "+", 
      RowBox[{"175497963696", " ", 
       SuperscriptBox["\[Zeta]", "7"]}], "-", 
      RowBox[{"25950904320", " ", 
       SuperscriptBox["\[Zeta]", "8"]}], "+", 
      RowBox[{"2295589857", " ", 
       SuperscriptBox["\[Zeta]", "9"]}], "-", 
      RowBox[{"92274688", " ", 
       SuperscriptBox["\[Zeta]", "10"]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "512"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "68855943984246"}], "+", 
      RowBox[{"286841433479375", " ", "\[Zeta]"}], "-", 
      RowBox[{"532824286571514", " ", 
       SuperscriptBox["\[Zeta]", "2"]}], "+", 
      RowBox[{"588628780050252", " ", 
       SuperscriptBox["\[Zeta]", "3"]}], "-", 
      RowBox[{"432784264349934", " ", 
       SuperscriptBox["\[Zeta]", "4"]}], "+", 
      RowBox[{"223476675537126", " ", 
       SuperscriptBox["\[Zeta]", "5"]}], "-", 
      RowBox[{"82985600360574", " ", 
       SuperscriptBox["\[Zeta]", "6"]}], "+", 
      RowBox[{"22212300913728", " ", 
       SuperscriptBox["\[Zeta]", "7"]}], "-", 
      RowBox[{"4205961859050", " ", 
       SuperscriptBox["\[Zeta]", "8"]}], "+", 
      RowBox[{"537004382464", " ", 
       SuperscriptBox["\[Zeta]", "9"]}], "-", 
      RowBox[{"41620660347", " ", 
       SuperscriptBox["\[Zeta]", "10"]}], "+", 
      RowBox[{"1483422720", " ", 
       SuperscriptBox["\[Zeta]", "11"]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.679049496858513*^9, 3.679222670062828*^9, 
  3.6792261883645287`*^9, 3.679226471836245*^9, 3.67922659121493*^9, 
  3.681448612075768*^9, 3.7124033781248503`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
We can see that all orders vanish at \[Zeta]=1 (the SUSY limit) if we plot \
them as a function of \[Zeta]\
\>", "Subsubsection",
 CellChangeTimes->{{3.677168066020935*^9, 3.677168076878347*^9}, {
  3.677168156829756*^9, 3.677168169051794*^9}, {3.677173873108816*^9, 
  3.6771738775999727`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"energyzet", ",", 
   RowBox[{"{", 
    RowBox[{"\[Zeta]", ",", ".5", ",", "1.5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.67716807869273*^9, 3.6771681256971073`*^9}, {
  3.677169620709332*^9, 3.677169691477902*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwl1Gs01HkcBvCpVq5by7q2Oo1L1mhzRESy31ZlcYphVUSTUatINYs23UdF
ty2Xtj1jdFHjGo2ZlGzhN4QmxvyUYqqNf0hmhsaYy3+pzdqzL57zvHpefN48
Dgn7In+eTaFQNszkv04itCYUCgHuYK2YnsbQEzrqf3I2AVHJ356ZnMIQeG8w
Za4BAUcu+7podBjszz2TmpkQIFZuSRhWYujyEuTbWRIQz7n+StKLwff07gVe
rgTkql07CqoxzHUfoCXSCdDy/Ku8tmEoPoyDJUUE1Bkx9+5slEJggaXJovC3
cKSzR9nE7IQvl6alD6nfwnCJnc0KewnsyY09nJE3AC79wcbz37SDx698g0vf
D0LR1zztyxNPwOHZAj8qMQiNse0XEIhhv0Ct8soZAuvr9lTO2zZgMCLXWPu/
g7VrYg92n22F9BMS2P36Hdh+TGTTQlrgg6sQBZ0dBmf+VXbqWDNcXlc98vuS
99CTfsO9p7wJni5bwRe2vwfGlTzelWQRsIpoZNSBEVh9LMapyrERArK85cm2
cjBT0mKjrj2EPaOVDMPHclgfRs8aGKwDT6cqVmqqAnzTwgN8fGrBuat1Cd1C
CSw0Qke1NXBwOiT5LlKC/WzZJvdZQvhU/D7iPHMUqLJmVommCgYkqvqRr8Zg
nJNp+yCjDLa2ZLZYNoyB7Rv16xibm2DguXR/zdYPIOj/7rbYmQvmjmsqZKYq
IBoKexWnLkLomdRsFl8F7LGt2/u2p4NpvxVb6TIO7CyViWh/GnJ6WPaZeXQc
ROIPFcejc1BkZNtTc+k4rA5t913ZXIDuuHGHTy1WA7XyZlJY9E30RnEnZNth
NXTddi/U3itDixKjZ6V1qGGcmW3lcb8K5TvWTIU4TkCuZcGLcAshsudyg7ek
TQDR9XztM24NYk22DT1tngB2xwqXHOtapC8obzaz04AAr7VKFNehSzprHTtJ
A5yq++WG6x8iZv7KpDqRBowuPQ95ZNCIghSKZTQLLdhWVD4uDhYhPY0InpWg
BVkZ28ngTBPqvXXuxpU6LcRVumWnDjQjPNwU9ouxDlYVGvq3Lm5Bk9v5AcZM
HQzl/Kl3PtWKxsT9h4zu6+Cu03Glw19t6O+Rq2Y/GOqB4B3w/GKhGC0PNSdW
MfTQ5bqOrcl4gk4nmhulVuvBnruOKm5oR8XJm47Nm9ZD7q2YSb9PHUhTTffZ
u5EECQp8WbexE8UIegMNS0nY0cQwXciRop6dtYv3lZEQff3lH/VXpShq0WWj
3nIS6EejHON4UkS/GCktrSRhtV+oXyFfioJTOmOChCRQhd477VqlyMf1ESur
ngRZkdkjqwkpsijiX5vTTUIw+8Gheesxyt18IXP385k9w3suPwKjefNTdnS/
IMF3lSBvw2aMjI/R3HgyEpz/Lin/LQEjSlzxvcA+EiisvB6TgxipbLiSTDkJ
9dt2eRqWYpSCM6rlChIEAYMNpZUYKbI350eMklD+DSMkSIjRsM4y2kFFAqf3
p/iseoz6unMGRVoSMsLh4pxujOLO721z1ZPAWvrAjifD6FXghopckoRdpt4l
gX0YvRCa7IufIiHqsVt9phyjyCR5hPjjjKek5EcHFUZdVPFyj39mPCep3SIt
RmGyUhvO5xkPs5ARP4WRJCdranqaBI///wv9CzoijgE=
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVkwk4lG0XxydCNGLiU1SvtTKliPJGyxG9krYxJbRYoo0s2UpKRJYkU6lE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      "]]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwdmHk8lG0Xx0WEkC1FyprQJlsSHVFCJaEslSgpkiZJpRSeJEWJeCwtkkSL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      "]]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVlnlcTesXxk8jjepo0KQ50aASUrK6RZN0k0rXVZpMaZJEuSgRkiQKkZKQ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      "]]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVl3k81N0XxweR7YksM8J8bSUqNZQl4d4ooZIsCRFSHmtTtJG1onpUTJtI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      "]]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVlnk8VN8bxyeVJC00IS22bFmisoQ8x9g1NGbuTakspU2K0LdSSqJS2SmR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      "]]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVlnk8lF8bxhVFlhakkrJFKEJZsnSfkKSSUKFMSPqFUGixlKUMssw8UbYK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      "]]}, 
    {RGBColor[1, 0.75, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwV1nk4VV0XAHAakHplJg000aBCRSFrJQkhISREUZmFSlSGQnOoVEqvRFGG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      "]]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[{{0.9829176309231484, -93777.02560981891}, {
      0.9900438905645015, -51929.14229491136}, {1.0095019343697824`, 
      45765.04476589172}, {1.0098317640389771`, 47289.42027842108}, {
      1.0101615937081716`, 48809.566704124474`}, {1.0108212530465606`, 
      51837.202832426716`}, {1.012140571723339, 57842.061360237574`}, {
      1.0147792090768954`, 69651.8198732255}, {1.0155989491372597`, 
      73198.57793317981}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[{{0.9992380474625827, -93777.02560981891}, {
      0.999772912467142, -27525.11191555072}, {1.0006383397427425`, 
      73198.57793317981}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[{{0.9999800246940581, -93777.02560981891}, {1.0000329320412957`, 
      73198.57793317981}}]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.6000000000000001, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0.5, 1.5}, {-93777.02560981891, 73198.57793317981}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6790495032629747`*^9, 3.679222673686092*^9, 
  3.679226594110486*^9, 3.6814486189961033`*^9, 3.712403381299906*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3: The Jacobi-Elliptic potential", "Subchapter",
 CellChangeTimes->{{3.678001858259715*^9, 3.678001891389722*^9}, {
  3.6780020885499573`*^9, 3.678002088636014*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox["BenderWu", TraditionalForm]]],
 " function can handle any potential as long as it has a polynomial power \
series around ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", " ", "=", " ", "0"}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.6780018972134438`*^9, 3.6780019067673798`*^9}, {
  3.678001985335279*^9, 3.678002010720071*^9}, {3.6780028875670843`*^9, 
  3.6780028915963287`*^9}, {3.678002980645512*^9, 3.678002986296774*^9}, {
  3.678003185231389*^9, 3.678003192022337*^9}, {3.678003237642479*^9, 
  3.6780032433361*^9}, {3.6792226899609013`*^9, 3.679222705040782*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"BW", "=", 
   RowBox[{"BenderWu", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"JacobiSN", "[", 
       RowBox[{"x", ",", "m"}], "]"}], "^", "2"}], ",", "x", ",", "3", ",", 
     "10", ",", 
     RowBox[{"Simplify", "\[Rule]", "True"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"BWProcess", "[", 
  RowBox[{"BW", ",", 
   RowBox[{"Order", "\[Rule]", "6"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6780020147994547`*^9, 3.678002044014606*^9}, {
   3.6780021013355494`*^9, 3.678002144527458*^9}, 3.6780022287038717`*^9, {
   3.6780055527003937`*^9, 3.678005553568344*^9}, {3.678005609536714*^9, 
   3.6780056119832973`*^9}, {3.6790479174266787`*^9, 3.679048015158901*^9}, {
   3.67922270633849*^9, 3.67922275107946*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["7", 
    SqrtBox["2"]], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["25", "8"]}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "m"}], ")"}]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"7", " ", 
      RowBox[{"(", 
       RowBox[{"13", "-", 
        RowBox[{"28", " ", "m"}], "+", 
        RowBox[{"13", " ", 
         SuperscriptBox["m", "2"]}]}], ")"}]}], 
     RowBox[{"32", " ", 
      SqrtBox["2"]}]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["855", "256"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "m"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "m"}], ")"}]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"7", " ", 
      RowBox[{"(", 
       RowBox[{"6233", "-", 
        RowBox[{"7036", " ", "m"}], "+", 
        RowBox[{"1614", " ", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"7036", " ", 
         SuperscriptBox["m", "3"]}], "+", 
        RowBox[{"6233", " ", 
         SuperscriptBox["m", "4"]}]}], ")"}]}], 
     RowBox[{"4096", " ", 
      SqrtBox["2"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"45", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "m"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"14697", "+", 
        RowBox[{"10519", " ", "m"}], "+", 
        RowBox[{"10519", " ", 
         SuperscriptBox["m", "2"]}], "+", 
        RowBox[{"14697", " ", 
         SuperscriptBox["m", "3"]}]}], ")"}]}], "32768"]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"7", " ", 
      RowBox[{"(", 
       RowBox[{"3216253", "-", 
        RowBox[{"4687914", " ", "m"}], "+", 
        RowBox[{"1484403", " ", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"25516", " ", 
         SuperscriptBox["m", "3"]}], "+", 
        RowBox[{"1484403", " ", 
         SuperscriptBox["m", "4"]}], "-", 
        RowBox[{"4687914", " ", 
         SuperscriptBox["m", "5"]}], "+", 
        RowBox[{"3216253", " ", 
         SuperscriptBox["m", "6"]}]}], ")"}]}], 
     RowBox[{"262144", " ", 
      SqrtBox["2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.679047931605661*^9, 3.679047958220151*^9}, 
   3.6790480318521013`*^9, 3.679049520745037*^9, {3.679222691604022*^9, 
   3.6792227530014668`*^9}, 3.679226597498417*^9, 3.681448623666079*^9, 
   3.712403386840396*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 4: Sine gordon level dependance of the perturbation theory\
\>", "Subchapter",
 CellChangeTimes->{{3.677172762515008*^9, 3.677172770366955*^9}, {
  3.6771728355664673`*^9, 3.6771728463345613`*^9}, {3.6780020901241302`*^9, 
  3.678002095345016*^9}, {3.678005441366908*^9, 3.6780054425800467`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "To establish the level dependance of the perturbation theory, up to order \
n=5, we make a table of of energy series for \[Nu]=0,1,...,6 level numbers \
(we use ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Monitor", "\[Rule]", "False"}], TraditionalForm]],
  FontColor->GrayLevel[0]],
 " option to suppress the monitor output)"
}], "Subsubsection",
 CellChangeTimes->{{3.677172774328629*^9, 3.677172924249926*^9}, {
  3.6771729624687853`*^9, 3.67717298634823*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BW3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"BenderWu", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", "x", "]"}], "^", "2"}], "/", "2"}], ",", "x", 
       ",", "nu", ",", "5", ",", 
       RowBox[{"Output", "\[Rule]", "\"\<Energy\>\""}], ",", 
       RowBox[{"Monitor", "\[Rule]", "False"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"nu", ",", "0", ",", "7"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.677172792904317*^9, 3.677172827412368*^9}, {
  3.67717292749503*^9, 3.677172947485032*^9}, {3.677173002179989*^9, 
  3.6771730265869217`*^9}, {3.679049619111269*^9, 3.67904964114723*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use ",
 Cell[BoxData[
  FormBox[
   StyleBox["BWLevelPolynomial",
    FontColor->GrayLevel[0]], TraditionalForm]]],
 " function to reconstruct the level depdendance at each order"
}], "Subsubsection",
 CellChangeTimes->{{3.6771730322023573`*^9, 3.677173062873835*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BW3levels", "=", 
  RowBox[{"BWLevelPolynomial", "[", "BW3", "]"}]}]], "Input",
 CellChangeTimes->{{3.677173065207864*^9, 3.677173070071697*^9}, {
  3.677173221393777*^9, 3.677173225880857*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], "+", "\[Nu]"}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "8"]}], "-", 
    FractionBox["\[Nu]", "4"], "-", 
    FractionBox[
     SuperscriptBox["\[Nu]", "2"], "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "32"]}], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[Nu]"}], "32"], "-", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["\[Nu]", "2"]}], "32"], "-", 
    FractionBox[
     SuperscriptBox["\[Nu]", "3"], "16"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "128"]}], "-", 
    FractionBox[
     RowBox[{"11", " ", "\[Nu]"}], "128"], "-", 
    FractionBox[
     SuperscriptBox["\[Nu]", "2"], "8"], "-", 
    FractionBox[
     RowBox[{"5", " ", 
      SuperscriptBox["\[Nu]", "3"]}], "64"], "-", 
    FractionBox[
     RowBox[{"5", " ", 
      SuperscriptBox["\[Nu]", "4"]}], "128"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["53", "2048"]}], "-", 
    FractionBox[
     RowBox[{"225", " ", "\[Nu]"}], "2048"], "-", 
    FractionBox[
     RowBox[{"195", " ", 
      SuperscriptBox["\[Nu]", "2"]}], "1024"], "-", 
    FractionBox[
     RowBox[{"185", " ", 
      SuperscriptBox["\[Nu]", "3"]}], "1024"], "-", 
    FractionBox[
     RowBox[{"165", " ", 
      SuperscriptBox["\[Nu]", "4"]}], "2048"], "-", 
    FractionBox[
     RowBox[{"33", " ", 
      SuperscriptBox["\[Nu]", "5"]}], "1024"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["297", "8192"]}], "-", 
    FractionBox[
     RowBox[{"1413", " ", "\[Nu]"}], "8192"], "-", 
    FractionBox[
     RowBox[{"1431", " ", 
      SuperscriptBox["\[Nu]", "2"]}], "4096"], "-", 
    FractionBox[
     RowBox[{"1575", " ", 
      SuperscriptBox["\[Nu]", "3"]}], "4096"], "-", 
    FractionBox[
     RowBox[{"2205", " ", 
      SuperscriptBox["\[Nu]", "4"]}], "8192"], "-", 
    FractionBox[
     RowBox[{"189", " ", 
      SuperscriptBox["\[Nu]", "5"]}], "2048"], "-", 
    FractionBox[
     RowBox[{"63", " ", 
      SuperscriptBox["\[Nu]", "6"]}], "2048"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.679049528950327*^9, {3.6790495837883263`*^9, 3.679049643819848*^9}, 
   3.679222764183239*^9, 3.679226609532578*^9, 3.6814486298442793`*^9, 
   3.71240339192705*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Note that the first element is just the simple HO level number dependance \
(zeroth order of perturbation theory). 
The level dependence of order, 3, for example is simply the fourth element of \
the above series.\
\>", "Subsubsection",
 CellChangeTimes->{{3.6771731862249193`*^9, 3.677173205549958*^9}, {
   3.677173249372884*^9, 3.677173294256955*^9}, 3.679049600679412*^9, {
   3.679049658997718*^9, 3.679049661281418*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BW3levels", "[", 
  RowBox[{"[", "4", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.677173264958126*^9, 3.677173268583048*^9}, {
  3.677173299732626*^9, 3.6771733014436417`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["3", "128"]}], "-", 
  FractionBox[
   RowBox[{"11", " ", "\[Nu]"}], "128"], "-", 
  FractionBox[
   SuperscriptBox["\[Nu]", "2"], "8"], "-", 
  FractionBox[
   RowBox[{"5", " ", 
    SuperscriptBox["\[Nu]", "3"]}], "64"], "-", 
  FractionBox[
   RowBox[{"5", " ", 
    SuperscriptBox["\[Nu]", "4"]}], "128"]}]], "Output",
 CellChangeTimes->{3.6790495338728657`*^9, 3.679049587072097*^9, 
  3.679049652566135*^9, 3.679222766301387*^9, 3.6792266116683273`*^9, 
  3.681448632225315*^9, 3.71240339757655*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["We can also change the symbol of the level-number", "Subsubsection",
 CellChangeTimes->{{3.677173376143095*^9, 3.6771733987955627`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BW3levels", "=", 
  RowBox[{"BWLevelPolynomial", "[", 
   RowBox[{"BW3", ",", "n"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.677173400492359*^9, 3.677173400764694*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], "+", "n"}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "8"]}], "-", 
    FractionBox["n", "4"], "-", 
    FractionBox[
     SuperscriptBox["n", "2"], "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "32"]}], "-", 
    FractionBox[
     RowBox[{"3", " ", "n"}], "32"], "-", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["n", "2"]}], "32"], "-", 
    FractionBox[
     SuperscriptBox["n", "3"], "16"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "128"]}], "-", 
    FractionBox[
     RowBox[{"11", " ", "n"}], "128"], "-", 
    FractionBox[
     SuperscriptBox["n", "2"], "8"], "-", 
    FractionBox[
     RowBox[{"5", " ", 
      SuperscriptBox["n", "3"]}], "64"], "-", 
    FractionBox[
     RowBox[{"5", " ", 
      SuperscriptBox["n", "4"]}], "128"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["53", "2048"]}], "-", 
    FractionBox[
     RowBox[{"225", " ", "n"}], "2048"], "-", 
    FractionBox[
     RowBox[{"195", " ", 
      SuperscriptBox["n", "2"]}], "1024"], "-", 
    FractionBox[
     RowBox[{"185", " ", 
      SuperscriptBox["n", "3"]}], "1024"], "-", 
    FractionBox[
     RowBox[{"165", " ", 
      SuperscriptBox["n", "4"]}], "2048"], "-", 
    FractionBox[
     RowBox[{"33", " ", 
      SuperscriptBox["n", "5"]}], "1024"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["297", "8192"]}], "-", 
    FractionBox[
     RowBox[{"1413", " ", "n"}], "8192"], "-", 
    FractionBox[
     RowBox[{"1431", " ", 
      SuperscriptBox["n", "2"]}], "4096"], "-", 
    FractionBox[
     RowBox[{"1575", " ", 
      SuperscriptBox["n", "3"]}], "4096"], "-", 
    FractionBox[
     RowBox[{"2205", " ", 
      SuperscriptBox["n", "4"]}], "8192"], "-", 
    FractionBox[
     RowBox[{"189", " ", 
      SuperscriptBox["n", "5"]}], "2048"], "-", 
    FractionBox[
     RowBox[{"63", " ", 
      SuperscriptBox["n", "6"]}], "2048"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.679049536180381*^9, 3.6790496698487167`*^9, 3.6792227677781*^9, 
   3.679226613707918*^9, 3.681448634647685*^9, {3.7124034004082727`*^9, 
   3.7124034157592154`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Notice that the function will issue a warning if we specified an insufficient \
number of level data, and return only result\
\>", "Subsubsection",
 CellChangeTimes->{{3.677173077759035*^9, 3.6771731811228933`*^9}, {
  3.67717321705756*^9, 3.677173218557633*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"BW3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"BenderWu", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", "x", "]"}], "^", "2"}], "/", "2"}], ",", "x", 
       ",", "nu", ",", "5", ",", 
       RowBox[{"Output", "\[Rule]", "\"\<Energy\>\""}], ",", 
       RowBox[{"Monitor", "\[Rule]", "False"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"nu", ",", "0", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"BW3levels", "=", 
  RowBox[{"BWLevelPolynomial", "[", "BW3", "]"}]}]}], "Input",
 CellChangeTimes->{{3.67717331405223*^9, 3.677173320489464*^9}, {
  3.67904970456837*^9, 3.679049704633313*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"WARNING: The polynomial form could not be established for the \
last \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" orders. \\nOutput is truncated to terms which \
are reliably found.\"\>"}],
  SequenceForm[
  "WARNING: The polynomial form could not be established for the last ", 2, 
   " orders. \nOutput is truncated to terms which are reliably found."],
  Editable->False]], "Print",
 CellChangeTimes->{3.679226629565937*^9, 3.681448636570816*^9, 
  3.712403423498061*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], "+", "\[Nu]"}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "8"]}], "-", 
    FractionBox["\[Nu]", "4"], "-", 
    FractionBox[
     SuperscriptBox["\[Nu]", "2"], "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "32"]}], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[Nu]"}], "32"], "-", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["\[Nu]", "2"]}], "32"], "-", 
    FractionBox[
     SuperscriptBox["\[Nu]", "3"], "16"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "128"]}], "-", 
    FractionBox[
     RowBox[{"11", " ", "\[Nu]"}], "128"], "-", 
    FractionBox[
     SuperscriptBox["\[Nu]", "2"], "8"], "-", 
    FractionBox[
     RowBox[{"5", " ", 
      SuperscriptBox["\[Nu]", "3"]}], "64"], "-", 
    FractionBox[
     RowBox[{"5", " ", 
      SuperscriptBox["\[Nu]", "4"]}], "128"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.679226629571149*^9, 3.681448636577704*^9, 
  3.712403423512846*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "The warning indicates that, although we asked ",
 Cell[BoxData[
  FormBox["BWLevelPolynomial", TraditionalForm]],
  FontColor->GrayLevel[0]],
 " to give the level-number dependance up to 5 orders, it truncated the last \
two orders because their correctness could not be established."
}], "Subsubsection",
 CellChangeTimes->{{3.677173329688137*^9, 3.677173365143017*^9}, {
  3.677173420673657*^9, 3.67717348909093*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 693},
WindowMargins->{{53, Automatic}, {Automatic, 0}},
TaggingRules->{ScrollPosition -> {0., 24.}, "$testsRun" -> False},
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->"Blue Theme.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info23681459254-2592033"->{
  Cell[2117, 67, 3515, 49, 969, "Print",
   CellTags->"Info23681459254-2592033"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info23681459254-2592033", 136539, 3461}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 132, 2, 92, "Title"],
Cell[715, 26, 410, 7, 135, "Title"],
Cell[1128, 35, 324, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[1477, 47, 138, 1, 109, "Chapter"],
Cell[1618, 50, 140, 2, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1795, 57, 177, 2, 65, "Chapter"],
Cell[CellGroupData[{
Cell[1997, 63, 117, 2, 28, "Input"],
Cell[2117, 67, 3515, 49, 969, "Print",
 CellTags->"Info23681459254-2592033"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5681, 122, 434, 11, 301, "Chapter"],
Cell[CellGroupData[{
Cell[6140, 137, 528, 7, 62, "Subchapter"],
Cell[CellGroupData[{
Cell[6693, 148, 136, 1, 35, "Subsubsection"],
Cell[6832, 151, 452, 14, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7321, 170, 399, 10, 59, "Subsubsection"],
Cell[7723, 182, 1299, 24, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9059, 211, 346, 9, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[9430, 224, 377, 6, 28, "Input"],
Cell[9810, 232, 1694, 45, 352, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11553, 283, 826, 25, 61, "Subsubsection"],
Cell[CellGroupData[{
Cell[12404, 312, 261, 5, 28, "Input"],
Cell[12668, 319, 1719, 46, 352, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14436, 371, 576, 15, 61, "Subsubsection"],
Cell[CellGroupData[{
Cell[15037, 390, 207, 4, 28, "Input"],
Cell[15247, 396, 2356, 65, 419, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17652, 467, 161, 2, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[17838, 473, 213, 5, 28, "Input"],
Cell[18054, 480, 3000, 82, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21103, 568, 675, 14, 37, "Subsubsection"],
Cell[CellGroupData[{
Cell[21803, 586, 460, 9, 28, "Input"],
Cell[22266, 597, 2495, 64, 419, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24810, 667, 228, 4, 59, "Subsubsection"],
Cell[25041, 673, 502, 14, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25580, 692, 337, 9, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[25942, 705, 366, 7, 28, "Input"],
Cell[26311, 714, 453, 15, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26813, 735, 362, 9, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[27200, 748, 313, 7, 28, "Input"],
Cell[27516, 757, 739, 18, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28304, 781, 547, 12, 83, "Subsubsection"],
Cell[CellGroupData[{
Cell[28876, 797, 548, 12, 28, "Input"],
Cell[29427, 811, 1573, 43, 76, "Output"]
}, Open  ]]
}, Open  ]],
Cell[31027, 858, 291, 7, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[31343, 869, 382, 11, 53, "Subsubsection"],
Cell[CellGroupData[{
Cell[31750, 884, 429, 10, 63, "Input"],
Cell[32182, 896, 1826, 29, 114, "Output"],
Cell[34011, 927, 2407, 51, 233, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36467, 984, 145, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[36637, 989, 210, 5, 28, "Input"],
Cell[36850, 996, 2283, 49, 233, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39182, 1051, 438, 13, 37, "Subsubsection"],
Cell[CellGroupData[{
Cell[39645, 1068, 561, 10, 28, "Input"],
Cell[40209, 1080, 3064, 96, 187, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[43322, 1182, 222, 6, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[43569, 1192, 381, 8, 46, "Input"],
Cell[43953, 1202, 3631, 124, 173, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47633, 1332, 356, 9, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[48014, 1345, 364, 7, 46, "Input"],
Cell[48381, 1354, 3109, 99, 193, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51539, 1459, 612, 15, 59, "Subsubsection"],
Cell[CellGroupData[{
Cell[52176, 1478, 467, 8, 28, "Input"],
Cell[52646, 1488, 3035, 80, 199, "Output"]
}, Open  ]]
}, Open  ]],
Cell[55708, 1572, 301, 8, 59, "Subsubsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56046, 1585, 134, 1, 62, "Subchapter"],
Cell[56183, 1588, 2059, 70, 287, "Subsubsection"],
Cell[CellGroupData[{
Cell[58267, 1662, 340, 11, 34, "Subsubsection"],
Cell[58610, 1675, 617, 20, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59264, 1700, 144, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[59433, 1705, 976, 18, 28, "Input"],
Cell[60412, 1725, 826, 13, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[61287, 1744, 151, 2, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[61463, 1750, 347, 9, 28, "Input"],
Cell[61813, 1761, 1613, 42, 314, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[63475, 1809, 506, 11, 59, "Subsubsection"],
Cell[CellGroupData[{
Cell[64006, 1824, 861, 17, 46, "Input"],
Cell[CellGroupData[{
Cell[64892, 1845, 563, 11, 24, "Print"],
Cell[65458, 1858, 344, 7, 24, "Print"]
}, Open  ]],
Cell[65817, 1868, 1353, 37, 238, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[67219, 1911, 405, 8, 59, "Subsubsection"],
Cell[CellGroupData[{
Cell[67649, 1923, 597, 13, 28, "Input"],
Cell[CellGroupData[{
Cell[68271, 1940, 602, 12, 24, "Print"],
Cell[68876, 1954, 367, 7, 24, "Print"]
}, Open  ]],
Cell[69258, 1964, 1453, 38, 200, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[70760, 2008, 529, 11, 85, "Subsubsection"],
Cell[CellGroupData[{
Cell[71314, 2023, 729, 21, 46, "Input"],
Cell[72046, 2046, 6406, 176, 471, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78501, 2228, 305, 6, 59, "Subsubsection"],
Cell[CellGroupData[{
Cell[78831, 2238, 272, 6, 28, "Input"],
Cell[79106, 2246, 41364, 698, 239, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[120531, 2951, 179, 2, 62, "Subchapter"],
Cell[CellGroupData[{
Cell[120735, 2957, 640, 14, 59, "Subsubsection"],
Cell[CellGroupData[{
Cell[121400, 2975, 771, 18, 46, "Input"],
Cell[122174, 2995, 2464, 78, 196, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[124699, 3080, 314, 5, 95, "Subchapter"],
Cell[CellGroupData[{
Cell[125038, 3089, 478, 11, 83, "Subsubsection"],
Cell[125519, 3102, 705, 17, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126261, 3124, 286, 8, 37, "Subsubsection"],
Cell[CellGroupData[{
Cell[126572, 3136, 218, 4, 28, "Input"],
Cell[126793, 3142, 2295, 74, 132, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[129137, 3222, 436, 8, 107, "Subsubsection"],
Cell[CellGroupData[{
Cell[129598, 3234, 202, 4, 28, "Input"],
Cell[129803, 3240, 560, 16, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[130412, 3262, 142, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[130579, 3267, 193, 4, 28, "Input"],
Cell[130775, 3273, 2212, 74, 132, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[133036, 3353, 273, 5, 59, "Subsubsection"],
Cell[CellGroupData[{
Cell[133334, 3362, 717, 19, 63, "Input"],
Cell[134054, 3383, 542, 11, 38, "Print"],
Cell[134599, 3396, 1047, 35, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[135673, 3435, 437, 9, 85, "Subsubsection"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

